from skidl import Pin, Part, SchLib, SKIDL, TEMPLATE

SKIDL_lib_version = '0.0.1'

intel = SchLib(tool=SKIDL).add_parts(*[
        Part(name='16450',dest=TEMPLATE,tool=SKIDL,keywords='1ch UART',description='PC8250A, Universal Asynchronous Receiver/Transmitter, PDIP-40',ref_prefix='U',num_units=1,fplist=['DIP*', 'PDIP*'],do_erc=True,aliases=['8250'],pins=[
            Pin(num='1',name='D0',func=Pin.BIDIR,do_erc=True),
            Pin(num='2',name='D1',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='D2',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='D3',func=Pin.BIDIR,do_erc=True),
            Pin(num='5',name='D4',func=Pin.BIDIR,do_erc=True),
            Pin(num='6',name='D5',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='D6',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='D7',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='RCLK',do_erc=True),
            Pin(num='10',name='SIN',do_erc=True),
            Pin(num='20',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='30',name='INTR',func=Pin.OUTPUT,do_erc=True),
            Pin(num='40',name='VCC',func=Pin.PWRIN,do_erc=True),
            Pin(num='11',name='SOUT',func=Pin.OUTPUT,do_erc=True),
            Pin(num='21',name='~RD~',do_erc=True),
            Pin(num='31',name='~OUT2~',func=Pin.OUTPUT,do_erc=True),
            Pin(num='12',name='CS0',do_erc=True),
            Pin(num='22',name='RD',do_erc=True),
            Pin(num='32',name='~RTS~',func=Pin.OUTPUT,do_erc=True),
            Pin(num='13',name='CS1',do_erc=True),
            Pin(num='23',name='DDIS',func=Pin.OUTPUT,do_erc=True),
            Pin(num='33',name='~DTR~',func=Pin.OUTPUT,do_erc=True),
            Pin(num='14',name='~CS2~',do_erc=True),
            Pin(num='24',name='CSOUT',func=Pin.OUTPUT,do_erc=True),
            Pin(num='34',name='~OUT1~',func=Pin.OUTPUT,do_erc=True),
            Pin(num='15',name='~BAUDOUT~',func=Pin.OUTPUT,do_erc=True),
            Pin(num='25',name='~ADS~',do_erc=True),
            Pin(num='35',name='MR',do_erc=True),
            Pin(num='16',name='XIN',do_erc=True),
            Pin(num='26',name='A2',do_erc=True),
            Pin(num='36',name='~CTS~',do_erc=True),
            Pin(num='17',name='XOUT',func=Pin.OUTPUT,do_erc=True),
            Pin(num='27',name='A1',do_erc=True),
            Pin(num='37',name='~DSR~',do_erc=True),
            Pin(num='18',name='~WR~',do_erc=True),
            Pin(num='28',name='A0',do_erc=True),
            Pin(num='38',name='~DCD~',do_erc=True),
            Pin(num='19',name='WR',do_erc=True),
            Pin(num='39',name='~RI~',do_erc=True)]),
        Part(name='16550',dest=TEMPLATE,tool=SKIDL,keywords='1ch UART FIFO',description='PC16550D, Universal Asynchronous Receiver/Transmitter with FIFOs, PDIP-40',ref_prefix='U',num_units=1,fplist=['DIP*', 'PDIP*'],do_erc=True,pins=[
            Pin(num='1',name='D0',func=Pin.BIDIR,do_erc=True),
            Pin(num='2',name='D1',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='D2',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='D3',func=Pin.BIDIR,do_erc=True),
            Pin(num='5',name='D4',func=Pin.BIDIR,do_erc=True),
            Pin(num='6',name='D5',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='D6',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='D7',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='RCLK',do_erc=True),
            Pin(num='10',name='SIN',do_erc=True),
            Pin(num='20',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='30',name='INTR',func=Pin.OUTPUT,do_erc=True),
            Pin(num='40',name='VCC',func=Pin.PWRIN,do_erc=True),
            Pin(num='11',name='SOUT',func=Pin.OUTPUT,do_erc=True),
            Pin(num='21',name='~RD~',do_erc=True),
            Pin(num='31',name='~OUT2~',func=Pin.OUTPUT,do_erc=True),
            Pin(num='12',name='CS0',do_erc=True),
            Pin(num='22',name='RD',do_erc=True),
            Pin(num='32',name='~RTS~',func=Pin.OUTPUT,do_erc=True),
            Pin(num='13',name='CS1',do_erc=True),
            Pin(num='23',name='DDIS',func=Pin.OUTPUT,do_erc=True),
            Pin(num='33',name='~DTR~',func=Pin.OUTPUT,do_erc=True),
            Pin(num='14',name='~CS2~',do_erc=True),
            Pin(num='24',name='~TXRDY~',func=Pin.OUTPUT,do_erc=True),
            Pin(num='34',name='~OUT1~',func=Pin.OUTPUT,do_erc=True),
            Pin(num='15',name='~BAUDOUT~',func=Pin.OUTPUT,do_erc=True),
            Pin(num='25',name='~ADS~',do_erc=True),
            Pin(num='35',name='MR',do_erc=True),
            Pin(num='16',name='XIN',do_erc=True),
            Pin(num='26',name='A2',do_erc=True),
            Pin(num='36',name='~CTS~',do_erc=True),
            Pin(num='17',name='XOUT',func=Pin.OUTPUT,do_erc=True),
            Pin(num='27',name='A1',do_erc=True),
            Pin(num='37',name='~DSR~',do_erc=True),
            Pin(num='18',name='~WR~',do_erc=True),
            Pin(num='28',name='A0',do_erc=True),
            Pin(num='38',name='~DCD~',do_erc=True),
            Pin(num='19',name='WR',do_erc=True),
            Pin(num='29',name='~RXRDY~',func=Pin.OUTPUT,do_erc=True),
            Pin(num='39',name='~RI~',do_erc=True)]),
        Part(name='8035',dest=TEMPLATE,tool=SKIDL,keywords='MCS-48 uC Microcontroller',description='MCS-48 8-bit Microcontroller, 4KB Mask ROM, 256B RAM, DIP-40',ref_prefix='U',num_units=1,fplist=['DIP*', 'PDIP*'],do_erc=True,aliases=['8039', '8040', '8048', '8049', '8050'],pins=[
            Pin(num='1',name='T0',do_erc=True),
            Pin(num='2',name='X1',do_erc=True),
            Pin(num='3',name='X2',func=Pin.OUTPUT,do_erc=True),
            Pin(num='4',name='~RESET~',do_erc=True),
            Pin(num='5',name='~SS~',do_erc=True),
            Pin(num='6',name='~INT~',do_erc=True),
            Pin(num='7',name='EA',do_erc=True),
            Pin(num='8',name='~RD~',func=Pin.OUTPUT,do_erc=True),
            Pin(num='9',name='~PSEN~',func=Pin.OUTPUT,do_erc=True),
            Pin(num='10',name='~WR~',func=Pin.OUTPUT,do_erc=True),
            Pin(num='20',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='30',name='P1.3',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='VCC',func=Pin.PWRIN,do_erc=True),
            Pin(num='11',name='ALE',func=Pin.OUTPUT,do_erc=True),
            Pin(num='21',name='P2.0',func=Pin.BIDIR,do_erc=True),
            Pin(num='31',name='P1.4',func=Pin.BIDIR,do_erc=True),
            Pin(num='12',name='DB.0',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='P2.1',func=Pin.BIDIR,do_erc=True),
            Pin(num='32',name='P1.5',func=Pin.BIDIR,do_erc=True),
            Pin(num='13',name='DB.1',func=Pin.BIDIR,do_erc=True),
            Pin(num='23',name='P2.2',func=Pin.BIDIR,do_erc=True),
            Pin(num='33',name='P1.6',func=Pin.BIDIR,do_erc=True),
            Pin(num='14',name='DB.2',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='P2.3',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='P1.7',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='DB.3',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='PROG',func=Pin.OUTPUT,do_erc=True),
            Pin(num='35',name='P2.4',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='DB.4',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='36',name='P2.5',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='DB.5',func=Pin.BIDIR,do_erc=True),
            Pin(num='27',name='P1.0',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='P2.6',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='DB.6',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='P1.1',func=Pin.BIDIR,do_erc=True),
            Pin(num='38',name='P2.7',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='DB.7',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='P1.2',func=Pin.BIDIR,do_erc=True),
            Pin(num='39',name='T1',do_erc=True)]),
        Part(name='8086_Max_Mode',dest=TEMPLATE,tool=SKIDL,keywords='MPRO',description='8086 (maximum mode), 16-Bit HMOS Microprocessor, PDIP-40',ref_prefix='U',num_units=1,fplist=['DIP*W15.24mm*', 'PDIP*W15.24mm*'],do_erc=True,pins=[
            Pin(num='1',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='2',name='AD14',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='AD13',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='AD12',func=Pin.BIDIR,do_erc=True),
            Pin(num='5',name='AD11',func=Pin.BIDIR,do_erc=True),
            Pin(num='6',name='AD10',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='AD9',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='AD8',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='AD7',func=Pin.BIDIR,do_erc=True),
            Pin(num='10',name='AD6',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='30',name='~RQ~/~GT1~',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='VCC',func=Pin.PWRIN,do_erc=True),
            Pin(num='11',name='AD5',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='RESET',do_erc=True),
            Pin(num='31',name='~RQ~/~GT0~',func=Pin.BIDIR,do_erc=True),
            Pin(num='12',name='AD4',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='READY',do_erc=True),
            Pin(num='32',name='~RD~',func=Pin.OUTPUT,do_erc=True),
            Pin(num='13',name='AD3',func=Pin.BIDIR,do_erc=True),
            Pin(num='23',name='~TEST~',do_erc=True),
            Pin(num='33',name='MN/~MX~',do_erc=True),
            Pin(num='14',name='AD2',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='QS1',func=Pin.OUTPUT,do_erc=True),
            Pin(num='34',name='~BHE~/S7',func=Pin.OUTPUT,do_erc=True),
            Pin(num='15',name='AD1',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='QS0',func=Pin.OUTPUT,do_erc=True),
            Pin(num='35',name='A19/S6',func=Pin.OUTPUT,do_erc=True),
            Pin(num='16',name='AD0',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='~S0~',func=Pin.OUTPUT,do_erc=True),
            Pin(num='36',name='A18/S5',func=Pin.OUTPUT,do_erc=True),
            Pin(num='17',name='NMI',do_erc=True),
            Pin(num='27',name='~S1~',func=Pin.OUTPUT,do_erc=True),
            Pin(num='37',name='A17/S4',func=Pin.OUTPUT,do_erc=True),
            Pin(num='18',name='INTR',do_erc=True),
            Pin(num='28',name='~S2~',func=Pin.OUTPUT,do_erc=True),
            Pin(num='38',name='A16/S3',func=Pin.OUTPUT,do_erc=True),
            Pin(num='19',name='CLK',do_erc=True),
            Pin(num='29',name='~LOCK~',func=Pin.OUTPUT,do_erc=True),
            Pin(num='39',name='AD15',func=Pin.BIDIR,do_erc=True)]),
        Part(name='8086_Min_Mode',dest=TEMPLATE,tool=SKIDL,keywords='MPRO',description='8086 (minimum mode), 16-Bit HMOS Microprocessor, PDIP-40',ref_prefix='U',num_units=1,fplist=['DIP*W15.24mm*', 'PDIP*W15.24mm*'],do_erc=True,pins=[
            Pin(num='1',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='2',name='AD14',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='AD13',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='AD12',func=Pin.BIDIR,do_erc=True),
            Pin(num='5',name='AD11',func=Pin.BIDIR,do_erc=True),
            Pin(num='6',name='AD10',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='AD9',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='AD8',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='AD7',func=Pin.BIDIR,do_erc=True),
            Pin(num='10',name='AD6',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='30',name='HLDA',func=Pin.OUTPUT,do_erc=True),
            Pin(num='40',name='VCC',func=Pin.PWRIN,do_erc=True),
            Pin(num='11',name='AD5',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='RESET',do_erc=True),
            Pin(num='31',name='HOLD',do_erc=True),
            Pin(num='12',name='AD4',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='READY',do_erc=True),
            Pin(num='32',name='~RD~',func=Pin.OUTPUT,do_erc=True),
            Pin(num='13',name='AD3',func=Pin.BIDIR,do_erc=True),
            Pin(num='23',name='~TEST~',do_erc=True),
            Pin(num='33',name='MN/~MX~',do_erc=True),
            Pin(num='14',name='AD2',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='~INTA~',func=Pin.OUTPUT,do_erc=True),
            Pin(num='34',name='~BHE~/S7',func=Pin.OUTPUT,do_erc=True),
            Pin(num='15',name='AD1',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='ALE',func=Pin.OUTPUT,do_erc=True),
            Pin(num='35',name='A19/S6',func=Pin.OUTPUT,do_erc=True),
            Pin(num='16',name='AD0',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='~DEN~',func=Pin.OUTPUT,do_erc=True),
            Pin(num='36',name='A18/S5',func=Pin.OUTPUT,do_erc=True),
            Pin(num='17',name='NMI',do_erc=True),
            Pin(num='27',name='DT/~R~',func=Pin.OUTPUT,do_erc=True),
            Pin(num='37',name='A17/S4',func=Pin.OUTPUT,do_erc=True),
            Pin(num='18',name='INTR',do_erc=True),
            Pin(num='28',name='M/~IO~',func=Pin.OUTPUT,do_erc=True),
            Pin(num='38',name='A16/S3',func=Pin.OUTPUT,do_erc=True),
            Pin(num='19',name='CLK',do_erc=True),
            Pin(num='29',name='~WR~',func=Pin.OUTPUT,do_erc=True),
            Pin(num='39',name='AD15',func=Pin.BIDIR,do_erc=True)]),
        Part(name='8087',dest=TEMPLATE,tool=SKIDL,keywords='FPU',description='Math Coprocessor for Intel 8086/8088/80186/80188 microprocessors, PDIP-40',ref_prefix='U',num_units=1,fplist=['DIP*W15.24mm*', 'PDIP*W15.24mm*'],do_erc=True,pins=[
            Pin(num='1',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='2',name='AD14',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='AD13',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='AD12',func=Pin.BIDIR,do_erc=True),
            Pin(num='5',name='AD11',func=Pin.BIDIR,do_erc=True),
            Pin(num='6',name='AD10',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='AD9',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='AD8',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='AD7',func=Pin.BIDIR,do_erc=True),
            Pin(num='10',name='AD6',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='30',name='NC',func=Pin.NOCONNECT,do_erc=True),
            Pin(num='40',name='VCC',func=Pin.PWRIN,do_erc=True),
            Pin(num='11',name='AD5',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='RESET',do_erc=True),
            Pin(num='31',name='~RQ~/~GT0~',func=Pin.BIDIR,do_erc=True),
            Pin(num='12',name='AD4',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='READY',do_erc=True),
            Pin(num='32',name='INT',func=Pin.OUTPUT,do_erc=True),
            Pin(num='13',name='AD3',func=Pin.BIDIR,do_erc=True),
            Pin(num='23',name='BUSY',func=Pin.OUTPUT,do_erc=True),
            Pin(num='33',name='~RQ~/~GT1~',func=Pin.BIDIR,do_erc=True),
            Pin(num='14',name='AD2',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='QS1',do_erc=True),
            Pin(num='34',name='~BHE~/S7',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='AD1',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='QS0',do_erc=True),
            Pin(num='35',name='A19/S6',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='AD0',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='~S0~',func=Pin.BIDIR,do_erc=True),
            Pin(num='36',name='A18/S5',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='NC',func=Pin.NOCONNECT,do_erc=True),
            Pin(num='27',name='~S1~',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='A17/S4',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='NC',func=Pin.NOCONNECT,do_erc=True),
            Pin(num='28',name='~S2~',func=Pin.BIDIR,do_erc=True),
            Pin(num='38',name='A16/S3',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='CLK',do_erc=True),
            Pin(num='29',name='NC',func=Pin.NOCONNECT,do_erc=True),
            Pin(num='39',name='AD15',func=Pin.BIDIR,do_erc=True)]),
        Part(name='8088',dest=TEMPLATE,tool=SKIDL,keywords='MPRO',description='8088 (minimum mode), 8-Bit HMOS Microprocessor, PDIP-40',ref_prefix='U',num_units=1,fplist=['DIP*W15.24mm*', 'PDIP*W15.24mm*'],do_erc=True,aliases=['8088_Min_Mode'],pins=[
            Pin(num='1',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='2',name='A14',func=Pin.OUTPUT,do_erc=True),
            Pin(num='3',name='A13',func=Pin.OUTPUT,do_erc=True),
            Pin(num='4',name='A12',func=Pin.OUTPUT,do_erc=True),
            Pin(num='5',name='A11',func=Pin.OUTPUT,do_erc=True),
            Pin(num='6',name='A10',func=Pin.OUTPUT,do_erc=True),
            Pin(num='7',name='A9',func=Pin.OUTPUT,do_erc=True),
            Pin(num='8',name='A8',func=Pin.OUTPUT,do_erc=True),
            Pin(num='9',name='AD7',func=Pin.BIDIR,do_erc=True),
            Pin(num='10',name='AD6',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='30',name='HLDA',func=Pin.OUTPUT,do_erc=True),
            Pin(num='40',name='VCC',func=Pin.PWRIN,do_erc=True),
            Pin(num='11',name='AD5',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='RESET',do_erc=True),
            Pin(num='31',name='HOLD',do_erc=True),
            Pin(num='12',name='AD4',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='READY',do_erc=True),
            Pin(num='32',name='~RD~',func=Pin.OUTPUT,do_erc=True),
            Pin(num='13',name='AD3',func=Pin.BIDIR,do_erc=True),
            Pin(num='23',name='~TEST~',do_erc=True),
            Pin(num='33',name='MN/~MX~',do_erc=True),
            Pin(num='14',name='AD2',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='~INTA~',func=Pin.OUTPUT,do_erc=True),
            Pin(num='34',name='~SSO~',func=Pin.OUTPUT,do_erc=True),
            Pin(num='15',name='AD1',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='ALE',func=Pin.OUTPUT,do_erc=True),
            Pin(num='35',name='A19/S6',func=Pin.OUTPUT,do_erc=True),
            Pin(num='16',name='AD0',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='DEN',func=Pin.OUTPUT,do_erc=True),
            Pin(num='36',name='A18/S5',func=Pin.OUTPUT,do_erc=True),
            Pin(num='17',name='NMI',do_erc=True),
            Pin(num='27',name='DT/~R~',func=Pin.OUTPUT,do_erc=True),
            Pin(num='37',name='A17/S4',func=Pin.OUTPUT,do_erc=True),
            Pin(num='18',name='INTR',do_erc=True),
            Pin(num='28',name='IO/~M~',func=Pin.OUTPUT,do_erc=True),
            Pin(num='38',name='A16/S3',func=Pin.OUTPUT,do_erc=True),
            Pin(num='19',name='CLK',do_erc=True),
            Pin(num='29',name='WR',func=Pin.OUTPUT,do_erc=True),
            Pin(num='39',name='A15',func=Pin.OUTPUT,do_erc=True)]),
        Part(name='8088_Max_Mode',dest=TEMPLATE,tool=SKIDL,keywords='MPRO',description='8088 (maximum mode), 8-Bit HMOS Microprocessor, PDIP-40',ref_prefix='U',num_units=1,fplist=['DIP*W15.24mm*', 'PDIP*W15.24mm*'],do_erc=True,pins=[
            Pin(num='1',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='2',name='A14',func=Pin.OUTPUT,do_erc=True),
            Pin(num='3',name='A13',func=Pin.OUTPUT,do_erc=True),
            Pin(num='4',name='A12',func=Pin.OUTPUT,do_erc=True),
            Pin(num='5',name='A11',func=Pin.OUTPUT,do_erc=True),
            Pin(num='6',name='A10',func=Pin.OUTPUT,do_erc=True),
            Pin(num='7',name='A9',func=Pin.OUTPUT,do_erc=True),
            Pin(num='8',name='A8',func=Pin.OUTPUT,do_erc=True),
            Pin(num='9',name='AD7',func=Pin.BIDIR,do_erc=True),
            Pin(num='10',name='AD6',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='30',name='~RQ~/~GT1~',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='VCC',func=Pin.PWRIN,do_erc=True),
            Pin(num='11',name='AD5',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='RESET',do_erc=True),
            Pin(num='31',name='~RQ~/~GT0~',func=Pin.BIDIR,do_erc=True),
            Pin(num='12',name='AD4',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='READY',do_erc=True),
            Pin(num='32',name='~RD~',func=Pin.OUTPUT,do_erc=True),
            Pin(num='13',name='AD3',func=Pin.BIDIR,do_erc=True),
            Pin(num='23',name='~TEST~',do_erc=True),
            Pin(num='33',name='MN/~MX~',do_erc=True),
            Pin(num='14',name='AD2',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='QS1',func=Pin.OUTPUT,do_erc=True),
            Pin(num='34',name='HIGH',func=Pin.OUTPUT,do_erc=True),
            Pin(num='15',name='AD1',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='QS0',func=Pin.OUTPUT,do_erc=True),
            Pin(num='35',name='A19/S6',func=Pin.OUTPUT,do_erc=True),
            Pin(num='16',name='AD0',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='~S0~',func=Pin.OUTPUT,do_erc=True),
            Pin(num='36',name='A18/S5',func=Pin.OUTPUT,do_erc=True),
            Pin(num='17',name='NMI',do_erc=True),
            Pin(num='27',name='~S1~',func=Pin.OUTPUT,do_erc=True),
            Pin(num='37',name='A17/S4',func=Pin.OUTPUT,do_erc=True),
            Pin(num='18',name='INTR',do_erc=True),
            Pin(num='28',name='~S2~',func=Pin.OUTPUT,do_erc=True),
            Pin(num='38',name='A16/S3',func=Pin.OUTPUT,do_erc=True),
            Pin(num='19',name='CLK',do_erc=True),
            Pin(num='29',name='~LOCK~',func=Pin.OUTPUT,do_erc=True),
            Pin(num='39',name='A15',func=Pin.OUTPUT,do_erc=True)]),
        Part(name='8252',dest=TEMPLATE,tool=SKIDL,keywords='UART Serial Interface',description='Universal Asynchronous Receiver/Transmitter, PDIP-28',ref_prefix='U',num_units=1,fplist=['DIP*', 'PDIP*'],do_erc=True,pins=[
            Pin(num='1',name='~RD~',do_erc=True),
            Pin(num='2',name='~WR~',do_erc=True),
            Pin(num='3',name='D0',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='D1',func=Pin.BIDIR,do_erc=True),
            Pin(num='5',name='D2',func=Pin.BIDIR,do_erc=True),
            Pin(num='6',name='D3',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='D4',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='D5',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='D6',func=Pin.BIDIR,do_erc=True),
            Pin(num='10',name='D7',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='~RTS~',func=Pin.OUTPUT,do_erc=True),
            Pin(num='11',name='A0',do_erc=True),
            Pin(num='21',name='CO',func=Pin.OUTPUT,do_erc=True),
            Pin(num='12',name='A1',do_erc=True),
            Pin(num='22',name='TBRE',func=Pin.OUTPUT,do_erc=True),
            Pin(num='13',name='IX',do_erc=True),
            Pin(num='23',name='RST',do_erc=True),
            Pin(num='14',name='OX',func=Pin.OUTPUT,do_erc=True),
            Pin(num='24',name='INTR',func=Pin.OUTPUT,do_erc=True),
            Pin(num='15',name='(TXD)SDO',func=Pin.OUTPUT,do_erc=True),
            Pin(num='25',name='(RXD)SDI',do_erc=True),
            Pin(num='16',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='26',name='DR',func=Pin.OUTPUT,do_erc=True),
            Pin(num='17',name='~CTS~',do_erc=True),
            Pin(num='27',name='VCC',func=Pin.PWRIN,do_erc=True),
            Pin(num='18',name='~DSR~',do_erc=True),
            Pin(num='28',name='CS0',do_erc=True),
            Pin(num='19',name='~DTR~',func=Pin.OUTPUT,do_erc=True)]),
        Part(name='8255',dest=TEMPLATE,tool=SKIDL,keywords='8255 PPI',description='CHMOS Programmable Peripheral Interface, PDIP-40',ref_prefix='U',num_units=1,fplist=['DIP*W15.24mm*', 'PDIP*W15.24mm*'],do_erc=True,aliases=['8255A', '82C55A'],pins=[
            Pin(num='1',name='PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='2',name='PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='5',name='~RD~',do_erc=True),
            Pin(num='6',name='~CS~',do_erc=True),
            Pin(num='7',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='8',name='A1',do_erc=True),
            Pin(num='9',name='A0',do_erc=True),
            Pin(num='10',name='PC7',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='D4',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='PC6',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='31',name='D3',func=Pin.BIDIR,do_erc=True),
            Pin(num='12',name='PC5',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='32',name='D2',func=Pin.BIDIR,do_erc=True),
            Pin(num='13',name='PC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='23',name='PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='33',name='D1',func=Pin.BIDIR,do_erc=True),
            Pin(num='14',name='PC0',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='D0',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='PC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='35',name='RESET',do_erc=True),
            Pin(num='16',name='PC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='VCC',func=Pin.PWRIN,do_erc=True),
            Pin(num='36',name='~WR~',do_erc=True),
            Pin(num='17',name='PC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='27',name='D7',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='D6',func=Pin.BIDIR,do_erc=True),
            Pin(num='38',name='PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='D5',func=Pin.BIDIR,do_erc=True),
            Pin(num='39',name='PA5',func=Pin.BIDIR,do_erc=True)]),
        Part(name='8259',dest=TEMPLATE,tool=SKIDL,keywords='PIC',description='8259, Programmable Interrupt Controller, PDIP-28',ref_prefix='U',num_units=1,fplist=['DIP*', 'PDIP*'],do_erc=True,aliases=['8259A', '8259A-2'],pins=[
            Pin(num='1',name='~CS~',do_erc=True),
            Pin(num='2',name='~RD~',do_erc=True),
            Pin(num='3',name='~WR~',do_erc=True),
            Pin(num='4',name='D7',func=Pin.BIDIR,do_erc=True),
            Pin(num='5',name='D6',func=Pin.BIDIR,do_erc=True),
            Pin(num='6',name='D5',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='D4',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='D3',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='D2',func=Pin.BIDIR,do_erc=True),
            Pin(num='10',name='D1',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='IR2',do_erc=True),
            Pin(num='11',name='D0',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='IR3',do_erc=True),
            Pin(num='12',name='CAS0',do_erc=True),
            Pin(num='22',name='IR4',do_erc=True),
            Pin(num='13',name='CAS1',func=Pin.OUTPUT,do_erc=True),
            Pin(num='23',name='IR5',do_erc=True),
            Pin(num='14',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='24',name='IR6',do_erc=True),
            Pin(num='15',name='CAS2',func=Pin.OUTPUT,do_erc=True),
            Pin(num='25',name='IR7',do_erc=True),
            Pin(num='16',name='~SP~/~EN~',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='~INTA~',do_erc=True),
            Pin(num='17',name='INT',func=Pin.OUTPUT,do_erc=True),
            Pin(num='27',name='A0',do_erc=True),
            Pin(num='18',name='IR0',do_erc=True),
            Pin(num='28',name='VCC',func=Pin.PWRIN,do_erc=True),
            Pin(num='19',name='IR1',do_erc=True)]),
        Part(name='82720',dest=TEMPLATE,tool=SKIDL,keywords='Graphics Controller',description='Graphics Display Controller, PDIP-40',ref_prefix='U',num_units=1,fplist=['PDIP*', 'DIP*'],do_erc=True,pins=[
            Pin(num='1',name='2xWCLK',do_erc=True),
            Pin(num='2',name='~DBIN',do_erc=True),
            Pin(num='3',name='HSYNC',func=Pin.OUTPUT,do_erc=True),
            Pin(num='4',name='VSYNC',func=Pin.BIDIR,do_erc=True),
            Pin(num='5',name='BLANK',func=Pin.OUTPUT,do_erc=True),
            Pin(num='6',name='(ALE)~RAS~',func=Pin.OUTPUT,do_erc=True),
            Pin(num='7',name='DREQ',func=Pin.OUTPUT,do_erc=True),
            Pin(num='8',name='~DACK~',do_erc=True),
            Pin(num='9',name='~RD~',do_erc=True),
            Pin(num='10',name='~WR~',do_erc=True),
            Pin(num='20',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='30',name='AD8',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='VCC',func=Pin.PWRIN,do_erc=True),
            Pin(num='11',name='A0',do_erc=True),
            Pin(num='21',name='LPEN',do_erc=True),
            Pin(num='31',name='AD9',func=Pin.BIDIR,do_erc=True),
            Pin(num='12',name='DB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='AD0',func=Pin.BIDIR,do_erc=True),
            Pin(num='32',name='AD10',func=Pin.BIDIR,do_erc=True),
            Pin(num='13',name='DB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='23',name='AD1',func=Pin.BIDIR,do_erc=True),
            Pin(num='33',name='AD14',func=Pin.BIDIR,do_erc=True),
            Pin(num='14',name='DB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='AD2',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='AD12',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='DB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='AD3',func=Pin.BIDIR,do_erc=True),
            Pin(num='35',name='AD13',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='DB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='AD4',func=Pin.BIDIR,do_erc=True),
            Pin(num='36',name='AD14',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='DB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='27',name='AD5',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='AD15',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='DB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='AD6',func=Pin.BIDIR,do_erc=True),
            Pin(num='38',name='A16',func=Pin.OUTPUT,do_erc=True),
            Pin(num='19',name='DB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='AD7',func=Pin.BIDIR,do_erc=True),
            Pin(num='39',name='A17',func=Pin.OUTPUT,do_erc=True)]),
        Part(name='8284',dest=TEMPLATE,tool=SKIDL,keywords='Clock Generator',description='Clock Generator and Driver for i8086/88 Microcontrollers, PDIP-18',ref_prefix='U',num_units=1,fplist=['DIP*W7.62mm*', 'PDIP*W7.62mm*'],do_erc=True,pins=[
            Pin(num='1',name='CSYNC',do_erc=True),
            Pin(num='2',name='PCLK',func=Pin.OUTPUT,do_erc=True),
            Pin(num='3',name='~AEN1~',do_erc=True),
            Pin(num='4',name='RDY1',do_erc=True),
            Pin(num='5',name='READY',func=Pin.OUTPUT,do_erc=True),
            Pin(num='6',name='RDY2',do_erc=True),
            Pin(num='7',name='~AEN2~',do_erc=True),
            Pin(num='8',name='CLK',func=Pin.OUTPUT,do_erc=True),
            Pin(num='9',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='10',name='RESET',func=Pin.OUTPUT,do_erc=True),
            Pin(num='11',name='~RES~',do_erc=True),
            Pin(num='12',name='OSC',func=Pin.OUTPUT,do_erc=True),
            Pin(num='13',name='F/~C~',do_erc=True),
            Pin(num='14',name='EFI',do_erc=True),
            Pin(num='15',name='~ASYNC~',do_erc=True),
            Pin(num='16',name='X2',func=Pin.OUTPUT,do_erc=True),
            Pin(num='17',name='X1',do_erc=True),
            Pin(num='18',name='VCC',func=Pin.PWRIN,do_erc=True)]),
        Part(name='8288',dest=TEMPLATE,tool=SKIDL,keywords='Bus Controller',description='Bus Controller for Intel 8086/8088/80186/80188 microprocessors, DIP-20',ref_prefix='U',num_units=1,fplist=['DIP*W7.62mm*', 'PDIP*W7.62mm*'],do_erc=True,pins=[
            Pin(num='1',name='IOB',do_erc=True),
            Pin(num='2',name='CLK',do_erc=True),
            Pin(num='3',name='~S1~',do_erc=True),
            Pin(num='4',name='DT/~R~',func=Pin.OUTPUT,do_erc=True),
            Pin(num='5',name='ALE',func=Pin.OUTPUT,do_erc=True),
            Pin(num='6',name='~AEN~',do_erc=True),
            Pin(num='7',name='~MRDC~',func=Pin.OUTPUT,do_erc=True),
            Pin(num='8',name='~AMWC~',func=Pin.OUTPUT,do_erc=True),
            Pin(num='9',name='~MWTC~',func=Pin.OUTPUT,do_erc=True),
            Pin(num='10',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='20',name='VCC',func=Pin.PWRIN,do_erc=True),
            Pin(num='11',name='~IOWC~',func=Pin.OUTPUT,do_erc=True),
            Pin(num='12',name='~AIOWC~',func=Pin.OUTPUT,do_erc=True),
            Pin(num='13',name='~IORC~',func=Pin.OUTPUT,do_erc=True),
            Pin(num='14',name='~INTA~',func=Pin.OUTPUT,do_erc=True),
            Pin(num='15',name='CEN',do_erc=True),
            Pin(num='16',name='DEN',func=Pin.OUTPUT,do_erc=True),
            Pin(num='17',name='MCE/~PDEN~',func=Pin.OUTPUT,do_erc=True),
            Pin(num='18',name='~S2~',do_erc=True),
            Pin(num='19',name='~S0~',do_erc=True)]),
        Part(name='82C54_PLCC',dest=TEMPLATE,tool=SKIDL,keywords='Timer Counter',description='82C54, Triple Channel Timer/Counter, PLCC-28',ref_prefix='U',num_units=1,do_erc=True,pins=[
            Pin(num='2',name='D7',do_erc=True),
            Pin(num='3',name='D6',do_erc=True),
            Pin(num='4',name='D5',do_erc=True),
            Pin(num='5',name='D4',do_erc=True),
            Pin(num='6',name='D3',do_erc=True),
            Pin(num='7',name='D2',do_erc=True),
            Pin(num='8',name='D1',do_erc=True),
            Pin(num='9',name='D0',do_erc=True),
            Pin(num='10',name='CLK0',do_erc=True),
            Pin(num='20',name='OUT2',func=Pin.OUTPUT,do_erc=True),
            Pin(num='21',name='CLK2',do_erc=True),
            Pin(num='12',name='OUT0',func=Pin.OUTPUT,do_erc=True),
            Pin(num='22',name='A0',do_erc=True),
            Pin(num='13',name='G0',do_erc=True),
            Pin(num='23',name='A1',do_erc=True),
            Pin(num='14',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='24',name='~CS~',do_erc=True),
            Pin(num='16',name='OUT1',func=Pin.OUTPUT,do_erc=True),
            Pin(num='26',name='~RD~',do_erc=True),
            Pin(num='17',name='G1',do_erc=True),
            Pin(num='27',name='~WR~',do_erc=True),
            Pin(num='18',name='CLK1',do_erc=True),
            Pin(num='28',name='VCC',func=Pin.PWRIN,do_erc=True),
            Pin(num='19',name='G2',do_erc=True)]),
        Part(name='82C55A_PLCC',dest=TEMPLATE,tool=SKIDL,keywords='8255 PPI',description='CHMOS Programmable Peripheral Interface, PLCC-44',ref_prefix='U',num_units=1,fplist=['*PLCC?44*'],do_erc=True,pins=[
            Pin(num='1',name='NC',func=Pin.NOCONNECT,do_erc=True),
            Pin(num='2',name='PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='5',name='PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='6',name='~RD~',do_erc=True),
            Pin(num='7',name='~CS~',do_erc=True),
            Pin(num='8',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='9',name='A1',do_erc=True),
            Pin(num='10',name='A0',do_erc=True),
            Pin(num='20',name='PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='D7',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='~WR~',do_erc=True),
            Pin(num='11',name='PC7',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='31',name='D6',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='12',name='NC',func=Pin.NOCONNECT,do_erc=True),
            Pin(num='22',name='PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='32',name='D5',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='13',name='PC6',func=Pin.BIDIR,do_erc=True),
            Pin(num='23',name='NC',func=Pin.NOCONNECT,do_erc=True),
            Pin(num='33',name='D4',func=Pin.BIDIR,do_erc=True),
            Pin(num='43',name='PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='14',name='PC5',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='NC',func=Pin.NOCONNECT,do_erc=True),
            Pin(num='44',name='PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='PC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='35',name='D3',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='PC0',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='36',name='D2',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='PC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='27',name='PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='D1',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='PC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='38',name='D0',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='PC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='VCC',func=Pin.PWRIN,do_erc=True),
            Pin(num='39',name='RESET',do_erc=True)]),
        Part(name='8748',dest=TEMPLATE,tool=SKIDL,keywords='MCS-48 uC Microcontroller',description='i8748, MCS-48 8-bit Microcontroller with Internal EPROM, 2KB EPROM, 128B RAM, DIP-40',ref_prefix='U',num_units=1,fplist=['DIP*', 'PDIP*'],do_erc=True,aliases=['8749'],pins=[
            Pin(num='1',name='T0',do_erc=True),
            Pin(num='2',name='X1',do_erc=True),
            Pin(num='3',name='X2',func=Pin.OUTPUT,do_erc=True),
            Pin(num='4',name='~RESET~',do_erc=True),
            Pin(num='5',name='~SS~',do_erc=True),
            Pin(num='6',name='~INT~',do_erc=True),
            Pin(num='7',name='EA',do_erc=True),
            Pin(num='8',name='~RD~',func=Pin.OUTPUT,do_erc=True),
            Pin(num='9',name='~PSEN~',func=Pin.OUTPUT,do_erc=True),
            Pin(num='10',name='~WR~',func=Pin.OUTPUT,do_erc=True),
            Pin(num='20',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='30',name='P1.3',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='VCC',func=Pin.PWRIN,do_erc=True),
            Pin(num='11',name='ALE',func=Pin.OUTPUT,do_erc=True),
            Pin(num='21',name='P2.0',func=Pin.BIDIR,do_erc=True),
            Pin(num='31',name='P1.4',func=Pin.BIDIR,do_erc=True),
            Pin(num='12',name='DB.0',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='P2.1',func=Pin.BIDIR,do_erc=True),
            Pin(num='32',name='P1.5',func=Pin.BIDIR,do_erc=True),
            Pin(num='13',name='DB.1',func=Pin.BIDIR,do_erc=True),
            Pin(num='23',name='P2.2',func=Pin.BIDIR,do_erc=True),
            Pin(num='33',name='P1.6',func=Pin.BIDIR,do_erc=True),
            Pin(num='14',name='DB.2',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='P2.3',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='P1.7',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='DB.3',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='PROG',func=Pin.OUTPUT,do_erc=True),
            Pin(num='35',name='P2.4',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='DB.4',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='Vpp/VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='36',name='P2.5',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='DB.5',func=Pin.BIDIR,do_erc=True),
            Pin(num='27',name='P1.0',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='P2.6',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='DB.6',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='P1.1',func=Pin.BIDIR,do_erc=True),
            Pin(num='38',name='P2.7',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='DB.7',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='P1.2',func=Pin.BIDIR,do_erc=True),
            Pin(num='39',name='T1',do_erc=True)]),
        Part(name='I386EX_PQFP',dest=TEMPLATE,tool=SKIDL,keywords='MPRO',description='Intel I386EX Embedded microprocessor, PQFP-132',ref_prefix='U',num_units=1,fplist=['PQFP*'],do_erc=True,pins=[
            Pin(num='1',name='UCS',func=Pin.OUTPUT,do_erc=True),
            Pin(num='2',name='CS6/REFRESH',func=Pin.OUTPUT,do_erc=True),
            Pin(num='3',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='4',name='LBA',func=Pin.OUTPUT,do_erc=True),
            Pin(num='5',name='D0',func=Pin.TRISTATE,do_erc=True),
            Pin(num='6',name='D1',func=Pin.TRISTATE,do_erc=True),
            Pin(num='7',name='D2',func=Pin.TRISTATE,do_erc=True),
            Pin(num='8',name='D3',func=Pin.TRISTATE,do_erc=True),
            Pin(num='9',name='VCC',func=Pin.PWRIN,do_erc=True),
            Pin(num='10',name='D4',func=Pin.TRISTATE,do_erc=True),
            Pin(num='20',name='D12',func=Pin.TRISTATE,do_erc=True),
            Pin(num='30',name='WR/RD',func=Pin.OUTPUT,do_erc=True),
            Pin(num='40',name='ADS',func=Pin.OUTPUT,do_erc=True),
            Pin(num='50',name='A7',func=Pin.TRISTATE,do_erc=True),
            Pin(num='60',name='VCC',func=Pin.PWRIN,do_erc=True),
            Pin(num='70',name='A24',func=Pin.TRISTATE,do_erc=True),
            Pin(num='80',name='INT0/P3.2',func=Pin.BIDIR,do_erc=True),
            Pin(num='90',name='NMI',do_erc=True),
            Pin(num='11',name='D5',func=Pin.TRISTATE,do_erc=True),
            Pin(num='21',name='D13',func=Pin.TRISTATE,do_erc=True),
            Pin(num='31',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='41',name='NA',do_erc=True),
            Pin(num='51',name='A8',func=Pin.TRISTATE,do_erc=True),
            Pin(num='61',name='A17/CAS1',func=Pin.TRISTATE,do_erc=True),
            Pin(num='71',name='VCC',func=Pin.PWRIN,do_erc=True),
            Pin(num='81',name='VCC',func=Pin.PWRIN,do_erc=True),
            Pin(num='91',name='ERROR/TMROUT2',func=Pin.BIDIR,do_erc=True),
            Pin(num='12',name='D6',func=Pin.TRISTATE,do_erc=True),
            Pin(num='22',name='D14',func=Pin.TRISTATE,do_erc=True),
            Pin(num='32',name='READY',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='A1',func=Pin.TRISTATE,do_erc=True),
            Pin(num='52',name='A9',func=Pin.TRISTATE,do_erc=True),
            Pin(num='62',name='A18/CAS2',func=Pin.TRISTATE,do_erc=True),
            Pin(num='72',name='A25',func=Pin.TRISTATE,do_erc=True),
            Pin(num='82',name='INT1/P3.3',func=Pin.BIDIR,do_erc=True),
            Pin(num='92',name='BUSY/TMRGATE2',do_erc=True),
            Pin(num='13',name='D7',func=Pin.TRISTATE,do_erc=True),
            Pin(num='23',name='D15',func=Pin.TRISTATE,do_erc=True),
            Pin(num='33',name='BS8',do_erc=True),
            Pin(num='43',name='A2',func=Pin.TRISTATE,do_erc=True),
            Pin(num='53',name='A10',func=Pin.TRISTATE,do_erc=True),
            Pin(num='63',name='A19',func=Pin.TRISTATE,do_erc=True),
            Pin(num='73',name='SMI',do_erc=True),
            Pin(num='83',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='93',name='INT4/TMRCLK0',do_erc=True),
            Pin(num='14',name='D8',func=Pin.TRISTATE,do_erc=True),
            Pin(num='24',name='TDO',func=Pin.OUTPUT,do_erc=True),
            Pin(num='34',name='RD',func=Pin.OUTPUT,do_erc=True),
            Pin(num='44',name='A3',func=Pin.TRISTATE,do_erc=True),
            Pin(num='54',name='A11',func=Pin.TRISTATE,do_erc=True),
            Pin(num='64',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='74',name='TMROUT0/P3.0',func=Pin.BIDIR,do_erc=True),
            Pin(num='84',name='INT2/P3.4',func=Pin.BIDIR,do_erc=True),
            Pin(num='94',name='INT5/TMRGATE0',do_erc=True),
            Pin(num='15',name='VCC',func=Pin.PWRIN,do_erc=True),
            Pin(num='25',name='TDI',do_erc=True),
            Pin(num='35',name='WR',func=Pin.OUTPUT,do_erc=True),
            Pin(num='45',name='A4',func=Pin.TRISTATE,do_erc=True),
            Pin(num='55',name='A12',func=Pin.TRISTATE,do_erc=True),
            Pin(num='65',name='A20',func=Pin.TRISTATE,do_erc=True),
            Pin(num='75',name='TMROUT1/P3.1',func=Pin.BIDIR,do_erc=True),
            Pin(num='85',name='INT3/P3.5',func=Pin.BIDIR,do_erc=True),
            Pin(num='95',name='INT6/TMRCLK1',do_erc=True),
            Pin(num='16',name='D9',func=Pin.TRISTATE,do_erc=True),
            Pin(num='26',name='TMS',do_erc=True),
            Pin(num='36',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='46',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='56',name='A13',func=Pin.TRISTATE,do_erc=True),
            Pin(num='66',name='A21',func=Pin.TRISTATE,do_erc=True),
            Pin(num='76',name='TCK',do_erc=True),
            Pin(num='86',name='PWRDWN/P3.6',func=Pin.BIDIR,do_erc=True),
            Pin(num='96',name='INT7/TMRGATE1',do_erc=True),
            Pin(num='17',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='27',name='M/IO',func=Pin.OUTPUT,do_erc=True),
            Pin(num='37',name='BLE',func=Pin.OUTPUT,do_erc=True),
            Pin(num='47',name='VCC',func=Pin.PWRIN,do_erc=True),
            Pin(num='57',name='A14',func=Pin.TRISTATE,do_erc=True),
            Pin(num='67',name='A22',func=Pin.TRISTATE,do_erc=True),
            Pin(num='77',name='SRXCLK/DTR1',func=Pin.BIDIR,do_erc=True),
            Pin(num='87',name='COMCLK/P3.7',func=Pin.BIDIR,do_erc=True),
            Pin(num='97',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='18',name='D10',func=Pin.TRISTATE,do_erc=True),
            Pin(num='28',name='VCC',func=Pin.PWRIN,do_erc=True),
            Pin(num='38',name='VCC',func=Pin.PWRIN,do_erc=True),
            Pin(num='48',name='A5',func=Pin.TRISTATE,do_erc=True),
            Pin(num='58',name='A15',func=Pin.TRISTATE,do_erc=True),
            Pin(num='68',name='A23',func=Pin.TRISTATE,do_erc=True),
            Pin(num='78',name='SSIORX/RI1',do_erc=True),
            Pin(num='88',name='VCC',func=Pin.PWRIN,do_erc=True),
            Pin(num='98',name='STXCLK/DSR1',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='D11',func=Pin.TRISTATE,do_erc=True),
            Pin(num='29',name='D/C',func=Pin.OUTPUT,do_erc=True),
            Pin(num='39',name='BHE',func=Pin.OUTPUT,do_erc=True),
            Pin(num='49',name='A6',func=Pin.TRISTATE,do_erc=True),
            Pin(num='59',name='A16/CAS0',func=Pin.TRISTATE,do_erc=True),
            Pin(num='69',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='79',name='SSIOTX/RST1',func=Pin.BIDIR,do_erc=True),
            Pin(num='89',name='PEREQ/TMRCLK2',do_erc=True),
            Pin(num='99',name='FLT',do_erc=True),
            Pin(num='100',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='110',name='RESET',do_erc=True),
            Pin(num='120',name='SMIACT',func=Pin.OUTPUT,do_erc=True),
            Pin(num='130',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='101',name='DCD0/P1.0',func=Pin.BIDIR,do_erc=True),
            Pin(num='111',name='HLDA/P1.7',func=Pin.BIDIR,do_erc=True),
            Pin(num='121',name='VCC',func=Pin.PWRIN,do_erc=True),
            Pin(num='131',name='TXD0/P2.6',func=Pin.BIDIR,do_erc=True),
            Pin(num='102',name='RTS0/P1.1',func=Pin.BIDIR,do_erc=True),
            Pin(num='112',name='DACK1/TXD1',func=Pin.OUTPUT,do_erc=True),
            Pin(num='122',name='CS0/P2.0',func=Pin.BIDIR,do_erc=True),
            Pin(num='132',name='CTS0/P2.7',func=Pin.BIDIR,do_erc=True),
            Pin(num='113',name='EOP/CTS1',func=Pin.BIDIR,do_erc=True),
            Pin(num='123',name='CS1/P2.1',func=Pin.BIDIR,do_erc=True),
            Pin(num='104',name='DTR0/P1.2',func=Pin.BIDIR,do_erc=True),
            Pin(num='114',name='WDTOUT',func=Pin.OUTPUT,do_erc=True),
            Pin(num='124',name='CS2/P2.2',func=Pin.BIDIR,do_erc=True),
            Pin(num='105',name='DSR0/P1.3',func=Pin.BIDIR,do_erc=True),
            Pin(num='115',name='CLK2',do_erc=True),
            Pin(num='125',name='CS3/P2.3',func=Pin.BIDIR,do_erc=True),
            Pin(num='106',name='RI0/P1.4',func=Pin.BIDIR,do_erc=True),
            Pin(num='116',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='126',name='CS4/P2.4',func=Pin.BIDIR,do_erc=True),
            Pin(num='107',name='LOCK/P1.5',func=Pin.BIDIR,do_erc=True),
            Pin(num='117',name='DRQ0/DCD1',do_erc=True),
            Pin(num='127',name='VCC',func=Pin.PWRIN,do_erc=True),
            Pin(num='108',name='HOLD/P1.6',func=Pin.BIDIR,do_erc=True),
            Pin(num='118',name='DRQ1/RXD1',do_erc=True),
            Pin(num='128',name='DACK0/CS5',func=Pin.OUTPUT,do_erc=True),
            Pin(num='109',name='VCC',func=Pin.PWRIN,do_erc=True),
            Pin(num='119',name='TRST',do_erc=True),
            Pin(num='129',name='RDX0/P2.5',func=Pin.BIDIR,do_erc=True)])])


from skidl import Pin, Part, SchLib, SKIDL, TEMPLATE

SKIDL_lib_version = '0.0.1'

power = SchLib(tool=SKIDL).add_parts(*[
        Part(name='+12C',dest=TEMPLATE,tool=SKIDL,do_erc=True),
        Part(name='+12L',dest=TEMPLATE,tool=SKIDL,do_erc=True),
        Part(name='+12LF',dest=TEMPLATE,tool=SKIDL,do_erc=True),
        Part(name='+12P',dest=TEMPLATE,tool=SKIDL,do_erc=True),
        Part(name='+12V',dest=TEMPLATE,tool=SKIDL,do_erc=True),
        Part(name='+12VA',dest=TEMPLATE,tool=SKIDL,do_erc=True),
        Part(name='+15V',dest=TEMPLATE,tool=SKIDL,do_erc=True),
        Part(name='+1V0',dest=TEMPLATE,tool=SKIDL,do_erc=True),
        Part(name='+1V1',dest=TEMPLATE,tool=SKIDL,do_erc=True),
        Part(name='+1V2',dest=TEMPLATE,tool=SKIDL,do_erc=True),
        Part(name='+1V35',dest=TEMPLATE,tool=SKIDL,do_erc=True),
        Part(name='+1V5',dest=TEMPLATE,tool=SKIDL,do_erc=True),
        Part(name='+1V8',dest=TEMPLATE,tool=SKIDL,do_erc=True),
        Part(name='+24V',dest=TEMPLATE,tool=SKIDL,do_erc=True),
        Part(name='+28V',dest=TEMPLATE,tool=SKIDL,do_erc=True),
        Part(name='+2V5',dest=TEMPLATE,tool=SKIDL,do_erc=True),
        Part(name='+2V8',dest=TEMPLATE,tool=SKIDL,do_erc=True),
        Part(name='+3.3VA',dest=TEMPLATE,tool=SKIDL,do_erc=True),
        Part(name='+3.3VADC',dest=TEMPLATE,tool=SKIDL,do_erc=True),
        Part(name='+3.3VDAC',dest=TEMPLATE,tool=SKIDL,do_erc=True),
        Part(name='+3.3VP',dest=TEMPLATE,tool=SKIDL,do_erc=True),
        Part(name='+36V',dest=TEMPLATE,tool=SKIDL,do_erc=True),
        Part(name='+3V3',dest=TEMPLATE,tool=SKIDL,do_erc=True,aliases=['+3.3V']),
        Part(name='+48V',dest=TEMPLATE,tool=SKIDL,do_erc=True),
        Part(name='+5C',dest=TEMPLATE,tool=SKIDL,do_erc=True),
        Part(name='+5F',dest=TEMPLATE,tool=SKIDL,do_erc=True),
        Part(name='+5P',dest=TEMPLATE,tool=SKIDL,do_erc=True),
        Part(name='+5V',dest=TEMPLATE,tool=SKIDL,do_erc=True),
        Part(name='+5VA',dest=TEMPLATE,tool=SKIDL,do_erc=True),
        Part(name='+5VD',dest=TEMPLATE,tool=SKIDL,do_erc=True),
        Part(name='+5VL',dest=TEMPLATE,tool=SKIDL,do_erc=True),
        Part(name='+5VP',dest=TEMPLATE,tool=SKIDL,do_erc=True),
        Part(name='+6V',dest=TEMPLATE,tool=SKIDL,do_erc=True),
        Part(name='+8V',dest=TEMPLATE,tool=SKIDL,do_erc=True),
        Part(name='+9V',dest=TEMPLATE,tool=SKIDL,do_erc=True),
        Part(name='+9VA',dest=TEMPLATE,tool=SKIDL,do_erc=True),
        Part(name='+BATT',dest=TEMPLATE,tool=SKIDL,do_erc=True),
        Part(name='-10V',dest=TEMPLATE,tool=SKIDL,keywords='POWER, PWR',ref_prefix='#PWR',num_units=1,do_erc=True,pins=[
            Pin(num='1',name='-10V',func=Pin.PWRIN,do_erc=True)]),
        Part(name='-12V',dest=TEMPLATE,tool=SKIDL,keywords='POWER, PWR',ref_prefix='#PWR',num_units=1,do_erc=True,pins=[
            Pin(num='1',name='-12V',func=Pin.PWRIN,do_erc=True)]),
        Part(name='-12VA',dest=TEMPLATE,tool=SKIDL,keywords='POWER, PWR',ref_prefix='#PWR',num_units=1,do_erc=True,pins=[
            Pin(num='1',name='-12VA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='-15V',dest=TEMPLATE,tool=SKIDL,keywords='POWER, PWR',ref_prefix='#PWR',num_units=1,do_erc=True,pins=[
            Pin(num='1',name='-15V',func=Pin.PWRIN,do_erc=True)]),
        Part(name='-24V',dest=TEMPLATE,tool=SKIDL,keywords='POWER, PWR',ref_prefix='#PWR',num_units=1,do_erc=True,pins=[
            Pin(num='1',name='-24V',func=Pin.PWRIN,do_erc=True)]),
        Part(name='-36V',dest=TEMPLATE,tool=SKIDL,keywords='POWER, PWR',ref_prefix='#PWR',num_units=1,do_erc=True,pins=[
            Pin(num='1',name='-36V',func=Pin.PWRIN,do_erc=True)]),
        Part(name='-48V',dest=TEMPLATE,tool=SKIDL,keywords='POWER, PWR',ref_prefix='#PWR',num_units=1,do_erc=True,pins=[
            Pin(num='1',name='-48V',func=Pin.PWRIN,do_erc=True)]),
        Part(name='-5V',dest=TEMPLATE,tool=SKIDL,keywords='POWER, PWR',ref_prefix='#PWR',num_units=1,do_erc=True,pins=[
            Pin(num='1',name='-5V',func=Pin.PWRIN,do_erc=True)]),
        Part(name='-5VA',dest=TEMPLATE,tool=SKIDL,keywords='POWER, PWR',ref_prefix='#PWR',num_units=1,do_erc=True,pins=[
            Pin(num='1',name='-5VA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='-6V',dest=TEMPLATE,tool=SKIDL,keywords='POWER, PWR',ref_prefix='#PWR',num_units=1,do_erc=True,pins=[
            Pin(num='1',name='-6V',func=Pin.PWRIN,do_erc=True)]),
        Part(name='-8V',dest=TEMPLATE,tool=SKIDL,keywords='POWER, PWR',ref_prefix='#PWR',num_units=1,do_erc=True,pins=[
            Pin(num='1',name='-8V',func=Pin.PWRIN,do_erc=True)]),
        Part(name='-9VA',dest=TEMPLATE,tool=SKIDL,keywords='POWER, PWR',ref_prefix='#PWR',num_units=1,do_erc=True,pins=[
            Pin(num='1',name='-9VA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='AC',dest=TEMPLATE,tool=SKIDL,keywords='POWER, PWR',ref_prefix='#PWR',num_units=1,do_erc=True,pins=[
            Pin(num='1',name='AC',func=Pin.PWRIN,do_erc=True)]),
        Part(name='~Earth',dest=TEMPLATE,tool=SKIDL,do_erc=True),
        Part(name='~Earth_Clean',dest=TEMPLATE,tool=SKIDL,do_erc=True),
        Part(name='~Earth_Protective',dest=TEMPLATE,tool=SKIDL,do_erc=True),
        Part(name='GND',dest=TEMPLATE,tool=SKIDL,keywords='POWER, PWR',ref_prefix='#PWR',num_units=1,do_erc=True,pins=[
            Pin(num='1',name='GND',func=Pin.PWRIN,do_erc=True)]),
        Part(name='GNDA',dest=TEMPLATE,tool=SKIDL,keywords='POWER, PWR',ref_prefix='#PWR',num_units=1,do_erc=True,pins=[
            Pin(num='1',name='GNDA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='GNDD',dest=TEMPLATE,tool=SKIDL,keywords='POWER, PWR',ref_prefix='#PWR',num_units=1,do_erc=True,pins=[
            Pin(num='1',name='GNDD',func=Pin.PWRIN,do_erc=True)]),
        Part(name='GNDPWR',dest=TEMPLATE,tool=SKIDL,keywords='POWER, PWR',ref_prefix='#PWR',num_units=1,do_erc=True,pins=[
            Pin(num='1',name='GNDPWR',func=Pin.PWRIN,do_erc=True)]),
        Part(name='GNDREF',dest=TEMPLATE,tool=SKIDL,keywords='POWER, PWR',ref_prefix='#PWR',num_units=1,do_erc=True,pins=[
            Pin(num='1',name='GNDREF',func=Pin.PWRIN,do_erc=True)]),
        Part(name='HT',dest=TEMPLATE,tool=SKIDL,do_erc=True),
        Part(name='PWR_FLAG',dest=TEMPLATE,tool=SKIDL,do_erc=True),
        Part(name='VAA',dest=TEMPLATE,tool=SKIDL,keywords='POWER, PWR',ref_prefix='#PWR',num_units=1,do_erc=True,pins=[
            Pin(num='1',name='VAA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='VCC',dest=TEMPLATE,tool=SKIDL,keywords='POWER, PWR',ref_prefix='#PWR',num_units=1,do_erc=True,pins=[
            Pin(num='1',name='VCC',func=Pin.PWRIN,do_erc=True)]),
        Part(name='VCOM',dest=TEMPLATE,tool=SKIDL,keywords='POWER, PWR',ref_prefix='#PWR',num_units=1,do_erc=True,pins=[
            Pin(num='1',name='VCOM',func=Pin.PWRIN,do_erc=True)]),
        Part(name='VDD',dest=TEMPLATE,tool=SKIDL,keywords='POWER, PWR',ref_prefix='#PWR',num_units=1,do_erc=True,pins=[
            Pin(num='1',name='VDD',func=Pin.PWRIN,do_erc=True)]),
        Part(name='VDDA',dest=TEMPLATE,tool=SKIDL,keywords='POWER, PWR',ref_prefix='#PWR',num_units=1,do_erc=True,pins=[
            Pin(num='1',name='VDDA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='VEE',dest=TEMPLATE,tool=SKIDL,keywords='POWER, PWR',ref_prefix='#PWR',num_units=1,do_erc=True,pins=[
            Pin(num='1',name='VEE',func=Pin.PWRIN,do_erc=True)]),
        Part(name='VMEM',dest=TEMPLATE,tool=SKIDL,keywords='POWER, PWR',ref_prefix='#PWR',num_units=1,do_erc=True,pins=[
            Pin(num='1',name='VMEM',func=Pin.PWRIN,do_erc=True)]),
        Part(name='VPP',dest=TEMPLATE,tool=SKIDL,keywords='POWER, PWR',ref_prefix='#PWR',num_units=1,do_erc=True,pins=[
            Pin(num='1',name='VPP',func=Pin.PWRIN,do_erc=True)]),
        Part(name='VSS',dest=TEMPLATE,tool=SKIDL,keywords='POWER, PWR',ref_prefix='#PWR',num_units=1,do_erc=True,pins=[
            Pin(num='1',name='VSS',func=Pin.PWRIN,do_erc=True)]),
        Part(name='VSSA',dest=TEMPLATE,tool=SKIDL,keywords='POWER, PWR',ref_prefix='#PWR',num_units=1,do_erc=True,pins=[
            Pin(num='1',name='VSSA',func=Pin.PWRIN,do_erc=True)])])


from skidl import Pin, Part, SchLib, SKIDL, TEMPLATE

SKIDL_lib_version = '0.0.1'

intersil = SchLib(tool=SKIDL).add_parts(*[
        Part(name='HIP2100_DFN',dest=TEMPLATE,tool=SKIDL,keywords='Half Bridge Gate Driver',description='High Frequency Half Bridge Driver, TTL/CMOS inputs, Output Current 2.0A, 100V, DFN-8 4x4mm',ref_prefix='U',num_units=1,fplist=['DFN*1EP*4x4mm*Pitch0.5mm*'],do_erc=True,aliases=['HIP2101_DFN'],pins=[
            Pin(num='1',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='2',name='NC',func=Pin.NOCONNECT,do_erc=True),
            Pin(num='3',name='NC',func=Pin.NOCONNECT,do_erc=True),
            Pin(num='4',name='HB',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='HO',func=Pin.OUTPUT,do_erc=True),
            Pin(num='6',name='HS',func=Pin.PASSIVE,do_erc=True),
            Pin(num='7',name='HI',do_erc=True),
            Pin(num='8',name='LI',do_erc=True),
            Pin(num='9',name='NC',func=Pin.NOCONNECT,do_erc=True),
            Pin(num='10',name='NC',func=Pin.NOCONNECT,do_erc=True),
            Pin(num='11',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='12',name='LO',func=Pin.OUTPUT,do_erc=True),
            Pin(num='13',name='EP',func=Pin.OUTPUT,do_erc=True)]),
        Part(name='HIP2100_EPSOIC',dest=TEMPLATE,tool=SKIDL,keywords='Half Bridge Gate Driver',description='High Frequency Half Bridge Driver, TTL/CMOS inputs, Output Current 2.0A, 100V, EPSOIC-8',ref_prefix='U',num_units=1,fplist=['SOIC*1EP*3.9x4.9mm*Pitch1.27mm*'],do_erc=True,aliases=['HIP2101_EPSOIC'],pins=[
            Pin(num='1',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='2',name='HB',func=Pin.PWRIN,do_erc=True),
            Pin(num='3',name='HO',func=Pin.OUTPUT,do_erc=True),
            Pin(num='4',name='HS',func=Pin.PASSIVE,do_erc=True),
            Pin(num='5',name='HI',do_erc=True),
            Pin(num='6',name='LI',do_erc=True),
            Pin(num='7',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='8',name='LO',func=Pin.OUTPUT,do_erc=True),
            Pin(num='9',name='EP',func=Pin.OUTPUT,do_erc=True)]),
        Part(name='HIP2100_QFN',dest=TEMPLATE,tool=SKIDL,keywords='Half Bridge Gate Driver',description='High Frequency Half Bridge Driver, TTL/CMOS inputs, Output Current 2.0A, 100V, QFN-16 5x5mm',ref_prefix='U',num_units=1,fplist=['QFN*1EP*5x5mm*Pitch0.8mm*'],do_erc=True,aliases=['HIP2101_QFN'],pins=[
            Pin(num='1',name='NC',func=Pin.NOCONNECT,do_erc=True),
            Pin(num='2',name='HB',func=Pin.PWRIN,do_erc=True),
            Pin(num='3',name='HO',func=Pin.OUTPUT,do_erc=True),
            Pin(num='4',name='NC',func=Pin.NOCONNECT,do_erc=True),
            Pin(num='5',name='NC',func=Pin.NOCONNECT,do_erc=True),
            Pin(num='6',name='HS',func=Pin.PASSIVE,do_erc=True),
            Pin(num='7',name='HI',do_erc=True),
            Pin(num='8',name='NC',func=Pin.NOCONNECT,do_erc=True),
            Pin(num='9',name='NC',func=Pin.NOCONNECT,do_erc=True),
            Pin(num='10',name='LI',do_erc=True),
            Pin(num='11',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='12',name='NC',func=Pin.NOCONNECT,do_erc=True),
            Pin(num='13',name='NC',func=Pin.NOCONNECT,do_erc=True),
            Pin(num='14',name='LO',func=Pin.OUTPUT,do_erc=True),
            Pin(num='15',name='NC',func=Pin.NOCONNECT,do_erc=True),
            Pin(num='16',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='17',name='EP',func=Pin.OUTPUT,do_erc=True)]),
        Part(name='HIP2100_SOIC',dest=TEMPLATE,tool=SKIDL,keywords='Half Bridge Gate Driver',description='High Frequency Half Bridge Driver, TTL/CMOS inputs, Output Current 2.0A, 100V, SOIC-8',ref_prefix='U',num_units=1,fplist=['SOIC*3.9x4.9mm*Pitch1.27mm*'],do_erc=True,aliases=['HIP2101_SOIC'],pins=[
            Pin(num='1',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='2',name='HB',func=Pin.PWRIN,do_erc=True),
            Pin(num='3',name='HO',func=Pin.OUTPUT,do_erc=True),
            Pin(num='4',name='HS',func=Pin.PASSIVE,do_erc=True),
            Pin(num='5',name='HI',do_erc=True),
            Pin(num='6',name='LI',do_erc=True),
            Pin(num='7',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='8',name='LO',func=Pin.OUTPUT,do_erc=True)]),
        Part(name='HIP4080A',dest=TEMPLATE,tool=SKIDL,keywords='Half Bridge Gate Driver',description='High Frequency Full Bridge FET Driver, Input Comparator, 2.5A, 80V',ref_prefix='U',num_units=1,fplist=['SOIC*7.5x12.8mm*Pitch1.27mm*', 'DIP*W7.62mm*'],do_erc=True,pins=[
            Pin(num='1',name='BHB',do_erc=True),
            Pin(num='2',name='HEN',func=Pin.OUTPUT,do_erc=True),
            Pin(num='3',name='DIS',func=Pin.OUTPUT,do_erc=True),
            Pin(num='4',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='OUT',func=Pin.OUTPUT,do_erc=True),
            Pin(num='6',name='IN+',do_erc=True),
            Pin(num='7',name='IN-',do_erc=True),
            Pin(num='8',name='HDEL',func=Pin.PASSIVE,do_erc=True),
            Pin(num='9',name='LDEL',func=Pin.PASSIVE,do_erc=True),
            Pin(num='10',name='AHB',do_erc=True),
            Pin(num='20',name='BHO',func=Pin.OUTPUT,do_erc=True),
            Pin(num='11',name='AHO',func=Pin.OUTPUT,do_erc=True),
            Pin(num='12',name='AHS',func=Pin.PASSIVE,do_erc=True),
            Pin(num='13',name='ALO',func=Pin.OUTPUT,do_erc=True),
            Pin(num='14',name='ALS',func=Pin.PASSIVE,do_erc=True),
            Pin(num='15',name='VCC',func=Pin.PWRIN,do_erc=True),
            Pin(num='16',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='17',name='BLS',func=Pin.PASSIVE,do_erc=True),
            Pin(num='18',name='BLO',func=Pin.OUTPUT,do_erc=True),
            Pin(num='19',name='BHS',func=Pin.PASSIVE,do_erc=True)]),
        Part(name='HIP4081A',dest=TEMPLATE,tool=SKIDL,keywords='Half Bridge Gate Driver',description='High Frequency Full Bridge FET Driver, 2.5A, 80V',ref_prefix='U',num_units=1,fplist=['SOIC*7.5x12.8mm*Pitch1.27mm*', 'DIP*W7.62mm*'],do_erc=True,pins=[
            Pin(num='1',name='BHB',do_erc=True),
            Pin(num='2',name='BHI',do_erc=True),
            Pin(num='3',name='DIS',func=Pin.OUTPUT,do_erc=True),
            Pin(num='4',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='BLI',do_erc=True),
            Pin(num='6',name='ALI',do_erc=True),
            Pin(num='7',name='AHI',do_erc=True),
            Pin(num='8',name='HDEL',func=Pin.PASSIVE,do_erc=True),
            Pin(num='9',name='LDEL',func=Pin.PASSIVE,do_erc=True),
            Pin(num='10',name='AHB',do_erc=True),
            Pin(num='20',name='BHO',func=Pin.OUTPUT,do_erc=True),
            Pin(num='11',name='AHO',func=Pin.OUTPUT,do_erc=True),
            Pin(num='12',name='AHS',func=Pin.PASSIVE,do_erc=True),
            Pin(num='13',name='ALO',func=Pin.OUTPUT,do_erc=True),
            Pin(num='14',name='ALS',func=Pin.PASSIVE,do_erc=True),
            Pin(num='15',name='VCC',func=Pin.PWRIN,do_erc=True),
            Pin(num='16',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='17',name='BLS',func=Pin.PASSIVE,do_erc=True),
            Pin(num='18',name='BLO',func=Pin.OUTPUT,do_erc=True),
            Pin(num='19',name='BHS',func=Pin.PASSIVE,do_erc=True)])])


from skidl import Pin, Part, SchLib, SKIDL, TEMPLATE

SKIDL_lib_version = '0.0.1'

microcontrollers = SchLib(tool=SKIDL).add_parts(*[
        Part(name='ADUC816',dest=TEMPLATE,tool=SKIDL,keywords='8051 CORE MCU ADC DAC',description='8KB Flash, 256B SRAM, 640B EEPROM, 16-bit ADC, 12-bit DAC, MQFP-52',ref_prefix='U',num_units=1,fplist=['MQFP*'],do_erc=True,pins=[
            Pin(num='1',name='P1.0(T2)',func=Pin.BIDIR,do_erc=True),
            Pin(num='2',name='P1.1(T2EX)',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='P1.2(DAC/IEXC1)',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='P1.3(AIN5/IEXC2)',func=Pin.BIDIR,do_erc=True),
            Pin(num='5',name='AVDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='6',name='AGND',func=Pin.PWRIN,do_erc=True),
            Pin(num='7',name='REF-',func=Pin.PASSIVE,do_erc=True),
            Pin(num='8',name='REF+',func=Pin.PASSIVE,do_erc=True),
            Pin(num='9',name='P1.4(AIN1)',do_erc=True),
            Pin(num='10',name='P1.5(AIN2)',do_erc=True),
            Pin(num='20',name='DVDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='30',name='(A10)P2.2',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='~EA~',func=Pin.BIDIR,do_erc=True),
            Pin(num='50',name='(AD5)P0.5',func=Pin.TRISTATE,do_erc=True),
            Pin(num='11',name='P1.6(AIN3)',do_erc=True),
            Pin(num='21',name='DGND',func=Pin.PWRIN,do_erc=True),
            Pin(num='31',name='(A11)P2.3',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='~PSEN~',func=Pin.OUTPUT,do_erc=True),
            Pin(num='51',name='(AD6)P0.6',func=Pin.TRISTATE,do_erc=True),
            Pin(num='12',name='P1.7(AIN4)',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='(T0)P3.4',func=Pin.BIDIR,do_erc=True),
            Pin(num='32',name='XTAL1',do_erc=True),
            Pin(num='42',name='ALE',func=Pin.OUTPUT,do_erc=True),
            Pin(num='52',name='(AD7)P0.7',func=Pin.TRISTATE,do_erc=True),
            Pin(num='13',name='~SS~',do_erc=True),
            Pin(num='23',name='(T1)P3.5',func=Pin.BIDIR,do_erc=True),
            Pin(num='33',name='XTAL2',func=Pin.OUTPUT,do_erc=True),
            Pin(num='43',name='(AD0)P0.0',func=Pin.TRISTATE,do_erc=True),
            Pin(num='14',name='MISO',do_erc=True),
            Pin(num='24',name='(~WR~)P3.6',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='DVDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='44',name='(AD1)P0.1',func=Pin.TRISTATE,do_erc=True),
            Pin(num='15',name='RESET',do_erc=True),
            Pin(num='25',name='(~RD~)P3.7',func=Pin.BIDIR,do_erc=True),
            Pin(num='35',name='DGND',func=Pin.PWRIN,do_erc=True),
            Pin(num='45',name='(AD2)P0.2',func=Pin.TRISTATE,do_erc=True),
            Pin(num='16',name='(RxD)P3.0',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='SCLOCK',func=Pin.BIDIR,do_erc=True),
            Pin(num='36',name='(A12)P2.4',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='(AD3)P0.3',func=Pin.TRISTATE,do_erc=True),
            Pin(num='17',name='(TxD)P3.1',func=Pin.BIDIR,do_erc=True),
            Pin(num='27',name='SDATA/MOSI',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='(A13)P2.5',func=Pin.BIDIR,do_erc=True),
            Pin(num='47',name='DGND',func=Pin.PWRIN,do_erc=True),
            Pin(num='18',name='(~INT0~)P3.2',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='(A8)P2.0',func=Pin.BIDIR,do_erc=True),
            Pin(num='38',name='(A14)P2.6',func=Pin.BIDIR,do_erc=True),
            Pin(num='48',name='DVDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='19',name='(~INT1~)P3.3',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='(A9)P2.1',func=Pin.BIDIR,do_erc=True),
            Pin(num='39',name='(A15)P2.7',func=Pin.BIDIR,do_erc=True),
            Pin(num='49',name='(AD4)P0.4',func=Pin.TRISTATE,do_erc=True)]),
        Part(name='P89LPC832A1FA',dest=TEMPLATE,tool=SKIDL,keywords='Philips 8051 Turbo Core',description='P89LPC932A1FA, 8kB Flash, 256 SRAM, 8bit MCS51 2-cycle Core Microcontroller, PLCC-28',ref_prefix='U',num_units=1,fplist=['PLCC*'],do_erc=True,pins=[
            Pin(num='1',name='ICB/P2.0',func=Pin.BIDIR,do_erc=True),
            Pin(num='2',name='OCD/P2.1',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='P0.0/CMP2/KBI0',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='P1.7/OCC',func=Pin.BIDIR,do_erc=True),
            Pin(num='5',name='P1.6/OCB',func=Pin.BIDIR,do_erc=True),
            Pin(num='6',name='P1.5/~RST',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='8',name='XTAL1/P3.1',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='CLKOUT/XTAL2/P3.0',func=Pin.BIDIR,do_erc=True),
            Pin(num='10',name='P1.4/~INT1',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='P0.6/CMP1/KBI6',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='P1.3/~INT0~/SDA',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='12',name='P1.2/T0/SCL',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='P0.5/CMPREF/KBI5',func=Pin.BIDIR,do_erc=True),
            Pin(num='13',name='MOSI/P2.2',func=Pin.BIDIR,do_erc=True),
            Pin(num='23',name='P0.4/CIN1A/KBI4',func=Pin.BIDIR,do_erc=True),
            Pin(num='14',name='MISO/P2.3',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='P0.3/CIN1B/KBI3',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='~SS~/P2.4',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='P0.2/CIN2A/KBI2',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='SPICLK/P2.5',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='P0.1/CIN2B/KBI1',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='P1.1/RXD',func=Pin.BIDIR,do_erc=True),
            Pin(num='27',name='OCA/P2.6',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='P1.0/TXD',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='ICA/P2.7',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='P0.7/T1/KB7',func=Pin.BIDIR,do_erc=True)]),
        Part(name='SAB80C515-M',dest=TEMPLATE,tool=SKIDL,keywords='CMOS MCU 8-bit',description='8KB ROM, 256B RAM, 8-bit CMOS High Performace Single-Chip Microcontroller, PMQFP-80',ref_prefix='U',num_units=1,fplist=['PLCC*'],do_erc=True,aliases=['SAB80C535-M'],pins=[
            Pin(num='1',name='~RESET~',do_erc=True),
            Pin(num='3',name='VAREF',func=Pin.PASSIVE,do_erc=True),
            Pin(num='4',name='VAGND',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='AN7/P6.7',do_erc=True),
            Pin(num='6',name='AN6/P6.6',do_erc=True),
            Pin(num='7',name='AN5/P6.5',do_erc=True),
            Pin(num='8',name='AN4/P6.4',do_erc=True),
            Pin(num='9',name='AN3/P6.3',do_erc=True),
            Pin(num='10',name='AN2/P6.2',do_erc=True),
            Pin(num='20',name='P3.5/T1',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='P1.1/INT4/CC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='P2.2',func=Pin.BIDIR,do_erc=True),
            Pin(num='60',name='P5.7',func=Pin.BIDIR,do_erc=True),
            Pin(num='80',name='P4.7',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='AN1/P6.1',do_erc=True),
            Pin(num='21',name='P3.6/~WR~',func=Pin.BIDIR,do_erc=True),
            Pin(num='31',name='P1.0/~INT3~/CC0',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='P2.3',func=Pin.BIDIR,do_erc=True),
            Pin(num='61',name='P5.6',func=Pin.BIDIR,do_erc=True),
            Pin(num='12',name='AN0/P6.0',do_erc=True),
            Pin(num='22',name='P3.7/~RD~',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='P2.4',func=Pin.BIDIR,do_erc=True),
            Pin(num='52',name='P0.0',func=Pin.BIDIR,do_erc=True),
            Pin(num='62',name='P5.5',func=Pin.BIDIR,do_erc=True),
            Pin(num='72',name='P4.0',func=Pin.BIDIR,do_erc=True),
            Pin(num='33',name='VCC',func=Pin.PWRIN,do_erc=True),
            Pin(num='43',name='P2.5',func=Pin.BIDIR,do_erc=True),
            Pin(num='53',name='P0.1',func=Pin.BIDIR,do_erc=True),
            Pin(num='63',name='P5.4',func=Pin.BIDIR,do_erc=True),
            Pin(num='73',name='P4.1',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='P1.7/T2',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='44',name='P2.6',func=Pin.BIDIR,do_erc=True),
            Pin(num='54',name='P0.2',func=Pin.BIDIR,do_erc=True),
            Pin(num='64',name='P5.3',func=Pin.BIDIR,do_erc=True),
            Pin(num='74',name='P4.2',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='P3.0/RXD',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='P1.6/CLKOUT',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='P2.7',func=Pin.BIDIR,do_erc=True),
            Pin(num='55',name='P0.3',func=Pin.BIDIR,do_erc=True),
            Pin(num='65',name='P5.2',func=Pin.BIDIR,do_erc=True),
            Pin(num='75',name='~PE~',do_erc=True),
            Pin(num='16',name='P3.1/TXD',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='P1.5/T2EX',func=Pin.BIDIR,do_erc=True),
            Pin(num='36',name='XTAL2',func=Pin.OUTPUT,do_erc=True),
            Pin(num='56',name='P0.4',func=Pin.BIDIR,do_erc=True),
            Pin(num='66',name='P5.1',func=Pin.BIDIR,do_erc=True),
            Pin(num='76',name='P4.3',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='P3.2/~INT0~',func=Pin.BIDIR,do_erc=True),
            Pin(num='27',name='P1.4/~INT2~',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='XTAL1',do_erc=True),
            Pin(num='47',name='~PSEN~',func=Pin.OUTPUT,do_erc=True),
            Pin(num='57',name='P0.5',func=Pin.BIDIR,do_erc=True),
            Pin(num='67',name='P5.0',func=Pin.BIDIR,do_erc=True),
            Pin(num='77',name='P4.4',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='P3.3/~INT1~',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='P1.3/INT6/CC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='38',name='P2.0',func=Pin.BIDIR,do_erc=True),
            Pin(num='48',name='ALE',func=Pin.OUTPUT,do_erc=True),
            Pin(num='58',name='P0.6',func=Pin.BIDIR,do_erc=True),
            Pin(num='78',name='P4.5',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='P3.4/T0',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='P1.2/INT5/CC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='39',name='P2.1',func=Pin.BIDIR,do_erc=True),
            Pin(num='49',name='~EA~',do_erc=True),
            Pin(num='59',name='P0.7',func=Pin.BIDIR,do_erc=True),
            Pin(num='69',name='VCC',func=Pin.PWRIN,do_erc=True),
            Pin(num='79',name='P4.6',func=Pin.BIDIR,do_erc=True)]),
        Part(name='SAB80C515-N',dest=TEMPLATE,tool=SKIDL,keywords='CMOS MCU 8-bit',description='SAB80C515-XX-N, 8KB ROM, 256B RAM, 8-bit CMOS High Performace Single-Chip Microcontroller, PLCC-68',ref_prefix='U',num_units=1,fplist=['PLCC*'],do_erc=True,aliases=['SAB80C535-N', 'SAB80C515-XX-N', 'SAB80C535-XX-N'],pins=[
            Pin(num='1',name='P4.0',func=Pin.BIDIR,do_erc=True),
            Pin(num='2',name='P4.1',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='P4.2',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='~PE~',do_erc=True),
            Pin(num='5',name='P4.3',func=Pin.BIDIR,do_erc=True),
            Pin(num='6',name='P4.4',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='P4.5',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='P4.6',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='P4.7',func=Pin.BIDIR,do_erc=True),
            Pin(num='10',name='~RESET~',do_erc=True),
            Pin(num='20',name='AN0/P6.0',do_erc=True),
            Pin(num='30',name='P1.6/CLKOUT',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='XTAL1',do_erc=True),
            Pin(num='50',name='ALE',func=Pin.OUTPUT,do_erc=True),
            Pin(num='60',name='P5.7',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='VAREF',func=Pin.PASSIVE,do_erc=True),
            Pin(num='21',name='P3.0/RXD',func=Pin.BIDIR,do_erc=True),
            Pin(num='31',name='P1.5/T2EX',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='P2.0',func=Pin.BIDIR,do_erc=True),
            Pin(num='51',name='~EA~',do_erc=True),
            Pin(num='61',name='P5.6',func=Pin.BIDIR,do_erc=True),
            Pin(num='12',name='VAGND',func=Pin.PWRIN,do_erc=True),
            Pin(num='22',name='P3.1/TXD',func=Pin.BIDIR,do_erc=True),
            Pin(num='32',name='P1.4/~INT2~',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='P2.1',func=Pin.BIDIR,do_erc=True),
            Pin(num='52',name='P0.0',func=Pin.BIDIR,do_erc=True),
            Pin(num='62',name='P5.5',func=Pin.BIDIR,do_erc=True),
            Pin(num='13',name='AN7/P6.7',do_erc=True),
            Pin(num='23',name='P3.2/~INT0~',func=Pin.BIDIR,do_erc=True),
            Pin(num='33',name='P1.3/INT6/CC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='43',name='P2.2',func=Pin.BIDIR,do_erc=True),
            Pin(num='53',name='P0.1',func=Pin.BIDIR,do_erc=True),
            Pin(num='63',name='P5.4',func=Pin.BIDIR,do_erc=True),
            Pin(num='14',name='AN6/P6.6',do_erc=True),
            Pin(num='24',name='P3.3/~INT1~',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='P1.2/INT5/CC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='44',name='P2.3',func=Pin.BIDIR,do_erc=True),
            Pin(num='54',name='P0.2',func=Pin.BIDIR,do_erc=True),
            Pin(num='64',name='P5.3',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='AN5/P6.5',do_erc=True),
            Pin(num='25',name='P3.4/T0',func=Pin.BIDIR,do_erc=True),
            Pin(num='35',name='P1.1/INT4/CC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='P2.4',func=Pin.BIDIR,do_erc=True),
            Pin(num='55',name='P0.3',func=Pin.BIDIR,do_erc=True),
            Pin(num='65',name='P5.2',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='AN4/P6.4',do_erc=True),
            Pin(num='26',name='P3.5/T1',func=Pin.BIDIR,do_erc=True),
            Pin(num='36',name='P1.0/~INT3~/CC0',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='P2.5',func=Pin.BIDIR,do_erc=True),
            Pin(num='56',name='P0.4',func=Pin.BIDIR,do_erc=True),
            Pin(num='66',name='P5.1',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='AN3/P6.3',do_erc=True),
            Pin(num='27',name='P3.6/~WR~',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='VCC',func=Pin.PWRIN,do_erc=True),
            Pin(num='47',name='P2.6',func=Pin.BIDIR,do_erc=True),
            Pin(num='57',name='P0.5',func=Pin.BIDIR,do_erc=True),
            Pin(num='67',name='P5.0',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='AN2/P6.2',do_erc=True),
            Pin(num='28',name='P3.7/~RD~',func=Pin.BIDIR,do_erc=True),
            Pin(num='38',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='48',name='P2.7',func=Pin.BIDIR,do_erc=True),
            Pin(num='58',name='P0.6',func=Pin.BIDIR,do_erc=True),
            Pin(num='68',name='VCC',func=Pin.PWRIN,do_erc=True),
            Pin(num='19',name='AN1/P6.1',do_erc=True),
            Pin(num='29',name='P1.7/T2',func=Pin.BIDIR,do_erc=True),
            Pin(num='39',name='XTAL2',func=Pin.OUTPUT,do_erc=True),
            Pin(num='49',name='~PSEN~',func=Pin.OUTPUT,do_erc=True),
            Pin(num='59',name='P0.7',func=Pin.BIDIR,do_erc=True)])])


from skidl import Pin, Part, SchLib, SKIDL, TEMPLATE

SKIDL_lib_version = '0.0.1'

diode = SchLib(tool=SKIDL).add_parts(*[
        Part(name='1N4001',dest=TEMPLATE,tool=SKIDL,keywords='diode',description='1000V 1A Fast recovery Rectifier Diode, DO-41',ref_prefix='D',num_units=1,fplist=['D*DO?41*', 'D*DO?204AL*', 'D*SOD81*'],do_erc=True,aliases=['1N4002', '1N4003', '1N4004', '1N4005', '1N4006', '1N4007', 'BA157', 'BA158', 'BA159'],pins=[
            Pin(num='1',name='K',func=Pin.PASSIVE,do_erc=True),
            Pin(num='2',name='A',func=Pin.PASSIVE,do_erc=True)]),
        Part(name='1N4148',dest=TEMPLATE,tool=SKIDL,keywords='diode',description='20V 0.115A Very Fast Switching Diode, DO-35',ref_prefix='D',num_units=1,fplist=['D*DO?35*', 'D*SOD27*'],do_erc=True,aliases=['1N4448', '1N4149', '1N4151', '1N914', 'BA243', 'BA244', 'BA282', 'BA283', 'BAV17', 'BAV18', 'BAV19', 'BAV20', 'BAV21', 'BAW75', 'BAW76', 'BAY93'],pins=[
            Pin(num='1',name='K',func=Pin.PASSIVE,do_erc=True),
            Pin(num='2',name='A',func=Pin.PASSIVE,do_erc=True)]),
        Part(name='1N5400',dest=TEMPLATE,tool=SKIDL,keywords='diode',description='1000V 3A Soft Recovery Ultrafast Rectifier Diode, DO-201AD',ref_prefix='D',num_units=1,fplist=['D*DO?201AD*'],do_erc=True,aliases=['1N5401', '1N5402', '1N5404', '1N5405', '1N5406', '1N5407', '1N5408', 'UF5400', 'UF5401', 'UF5402', 'UF5403', 'UF5404', 'UF5405', 'UF5406', 'UF5407', 'UF5408', '1N5403'],pins=[
            Pin(num='1',name='K',func=Pin.PASSIVE,do_erc=True),
            Pin(num='2',name='A',func=Pin.PASSIVE,do_erc=True)]),
        Part(name='1N5820',dest=TEMPLATE,tool=SKIDL,keywords='diode Schottky',description='40V 3A Schottky Barrier Rectifier Diode, DO-201AD',ref_prefix='D',num_units=1,fplist=['D*DO?201AD*'],do_erc=True,aliases=['1N5821', '1N5822', 'MBR340'],pins=[
            Pin(num='1',name='K',func=Pin.PASSIVE,do_erc=True),
            Pin(num='2',name='A',func=Pin.PASSIVE,do_erc=True)]),
        Part(name='1N6263',dest=TEMPLATE,tool=SKIDL,keywords='diode Schottky',description='50V 0.2A Small Signal Schottky Diode, DO-35',ref_prefix='D',num_units=1,fplist=['D*SOD23*', 'D*DO?35*'],do_erc=True,aliases=['BAT41', 'BAT42', 'BAT43', 'BAT46', 'BAT48RL', 'BAT85', 'BAT86S', 'BAT86'],pins=[
            Pin(num='1',name='K',func=Pin.PASSIVE,do_erc=True),
            Pin(num='2',name='A',func=Pin.PASSIVE,do_erc=True)]),
        Part(name='B120-E3',dest=TEMPLATE,tool=SKIDL,keywords='diode Schottky',description='60V 1A Schottky Barrier Rectifier Diode, SMA/DO-214AC',ref_prefix='D',num_units=1,fplist=['D*DO?214AC*', 'D*SMA*', 'DO?214AC*', 'SMA*'],do_erc=True,aliases=['B130-E3', 'B140-E3', 'B150-E3', 'B160-E3'],pins=[
            Pin(num='1',name='K',func=Pin.PASSIVE,do_erc=True),
            Pin(num='2',name='A',func=Pin.PASSIVE,do_erc=True)]),
        Part(name='B220',dest=TEMPLATE,tool=SKIDL,keywords='diode Schottky',description='60V 2A Schottky Barrier Rectifier Diode, SMB',ref_prefix='D',num_units=1,fplist=['D*DO?214AC*', 'D*SMA*', 'DO?214AC*', 'SMA*'],do_erc=True,aliases=['B230', 'B240', 'B250', 'B260'],pins=[
            Pin(num='1',name='K',func=Pin.PASSIVE,do_erc=True),
            Pin(num='2',name='A',func=Pin.PASSIVE,do_erc=True)]),
        Part(name='B320',dest=TEMPLATE,tool=SKIDL,keywords='diode Schottky',description='60V 3A Schottky Barrier Rectifier Diode, SMC',ref_prefix='D',num_units=1,fplist=['D*DO?214AC*', 'D*SMA*', 'DO?214AC*', 'SMA*'],do_erc=True,aliases=['B330', 'B340', 'B350', 'B360'],pins=[
            Pin(num='1',name='K',func=Pin.PASSIVE,do_erc=True),
            Pin(num='2',name='A',func=Pin.PASSIVE,do_erc=True)]),
        Part(name='BAR42FILM',dest=TEMPLATE,tool=SKIDL,keywords='diode Schottky',description='30V 0.1A Small signal Schottky diode, SOT-23',ref_prefix='D',num_units=1,fplist=['SOT?23*'],do_erc=True,aliases=['BAR43FILM'],pins=[
            Pin(num='1',name='A',func=Pin.PASSIVE,do_erc=True),
            Pin(num='2',name='NC',func=Pin.NOCONNECT,do_erc=True),
            Pin(num='3',name='K',func=Pin.PASSIVE,do_erc=True)]),
        Part(name='BAS16TW',dest=TEMPLATE,tool=SKIDL,keywords='diode',description='Fast switching diode array 3 independent',ref_prefix='D',num_units=3,fplist=['*SC-70-6*', '*SC-88*', '*SOT-363*'],do_erc=True,aliases=['BAS16VY', 'MMBD4148TW', 'MMBD4448HTW', 'HN2D02FU', 'Comchip_ACDSV6-4448TI-G', 'Central_Semi_CMKD6001', 'Central_Semi_CMKD4448', 'Comchip_CDSV6-4148-G', 'Comchip_CDSV6-4448TI-G'],pins=[
            Pin(num='1',name='A',func=Pin.PASSIVE,do_erc=True),
            Pin(num='6',name='K',func=Pin.PASSIVE,do_erc=True),
            Pin(num='2',name='A',func=Pin.PASSIVE,do_erc=True),
            Pin(num='5',name='K',func=Pin.PASSIVE,do_erc=True),
            Pin(num='3',name='A',func=Pin.PASSIVE,do_erc=True),
            Pin(num='4',name='K',func=Pin.PASSIVE,do_erc=True)]),
        Part(name='BAT48JFILM',dest=TEMPLATE,tool=SKIDL,keywords='diode Schottky',description='40V 0.35A Small Signal Schottky Diode, SOD-323',ref_prefix='D',num_units=1,fplist=['D*SOD?323*'],do_erc=True,pins=[
            Pin(num='1',name='K',func=Pin.PASSIVE,do_erc=True),
            Pin(num='2',name='A',func=Pin.PASSIVE,do_erc=True)]),
        Part(name='BAT48ZFILM',dest=TEMPLATE,tool=SKIDL,keywords='diode Schottky',description='80V 0.5A Schottky Power Rectifier Diode, SOD-123',ref_prefix='D',num_units=1,fplist=['D*SOD?123*'],do_erc=True,aliases=['MBR0520LT', 'MBR0520', 'MBR0530', 'MBR0540', 'MBR0550', 'MBR0560', 'MBR0570', 'MBR0580', 'BAT42W-V', 'BAT43W-V'],pins=[
            Pin(num='1',name='K',func=Pin.PASSIVE,do_erc=True),
            Pin(num='2',name='A',func=Pin.PASSIVE,do_erc=True)]),
        Part(name='BAT54A',dest=TEMPLATE,tool=SKIDL,keywords='schottky diode',description='schottky barrier diode',ref_prefix='D',num_units=1,fplist=['SOT-23*'],do_erc=True,pins=[
            Pin(num='1',name='~',func=Pin.PASSIVE,do_erc=True),
            Pin(num='2',name='~',func=Pin.PASSIVE,do_erc=True),
            Pin(num='3',name='~',func=Pin.PASSIVE,do_erc=True)]),
        Part(name='BAT54ADW',dest=TEMPLATE,tool=SKIDL,keywords='diode',description='Schottky diode array 2 pair Com A',ref_prefix='D',num_units=4,fplist=['*SC-70-6*', '*SC-88*', '*SOT-363*'],do_erc=True,pins=[
            Pin(num='1',name='K',func=Pin.PASSIVE,do_erc=True),
            Pin(num='6',name='A',func=Pin.PASSIVE,do_erc=True),
            Pin(num='2',name='K',func=Pin.PASSIVE,do_erc=True),
            Pin(num='6',name='A',func=Pin.PASSIVE,do_erc=True),
            Pin(num='3',name='A',func=Pin.PASSIVE,do_erc=True),
            Pin(num='4',name='K',func=Pin.PASSIVE,do_erc=True),
            Pin(num='3',name='A',func=Pin.PASSIVE,do_erc=True),
            Pin(num='5',name='K',func=Pin.PASSIVE,do_erc=True)]),
        Part(name='BAV99',dest=TEMPLATE,tool=SKIDL,keywords='diode',description='BAV99 High-speed switching diodes',ref_prefix='D',num_units=2,fplist=['SOT?23*'],do_erc=True,pins=[
            Pin(num='1',name='A',func=Pin.PASSIVE,do_erc=True),
            Pin(num='3',name='K',func=Pin.PASSIVE,do_erc=True),
            Pin(num='2',name='K',func=Pin.PASSIVE,do_erc=True),
            Pin(num='3',name='A',func=Pin.PASSIVE,do_erc=True)]),
        Part(name='BYV79-100',dest=TEMPLATE,tool=SKIDL,keywords='diode',description='200V 14A Ultrafast Rectifier Diode, TO-220',ref_prefix='D',num_units=1,fplist=['TO?220*'],do_erc=True,aliases=['BYV79-200', 'BYV79-150'],pins=[
            Pin(num='1',name='K',func=Pin.PASSIVE,do_erc=True),
            Pin(num='2',name='A',func=Pin.PASSIVE,do_erc=True)]),
        Part(name='DB3',dest=TEMPLATE,tool=SKIDL,keywords='AC diode DIAC',description='40V 2A Bidirectional trigger diode, DO-35',ref_prefix='D',num_units=1,fplist=['D*SOD27*', 'D*DO?35*'],do_erc=True,aliases=['DB4', 'DC34'],pins=[
            Pin(num='1',name='K',func=Pin.PASSIVE,do_erc=True),
            Pin(num='2',name='A',func=Pin.PASSIVE,do_erc=True)]),
        Part(name='LL41',dest=TEMPLATE,tool=SKIDL,keywords='diode Schottky',description='30V 0.2A Small Signal Schottky diode, MiniMELF',ref_prefix='D',num_units=1,fplist=['D*MiniMELF*', 'MiniMELF*'],do_erc=True,aliases=['LL42', 'LL43'],pins=[
            Pin(num='1',name='K',func=Pin.PASSIVE,do_erc=True),
            Pin(num='2',name='A',func=Pin.PASSIVE,do_erc=True)]),
        Part(name='LL4148',dest=TEMPLATE,tool=SKIDL,keywords='diode',description='100V 0.15A standard switching diode, MiniMELF',ref_prefix='D',num_units=1,fplist=['D*MiniMELF*', 'MiniMELF*'],do_erc=True,aliases=['LL4448'],pins=[
            Pin(num='1',name='K',func=Pin.PASSIVE,do_erc=True),
            Pin(num='2',name='A',func=Pin.PASSIVE,do_erc=True)]),
        Part(name='MBR735',dest=TEMPLATE,tool=SKIDL,keywords='diode Schottky',description='45V 7.5A Schottky Barrier Rectifier Diode, TO-220',ref_prefix='D',num_units=1,fplist=['TO?220*'],do_erc=True,aliases=['MBR745'],pins=[
            Pin(num='1',name='K',func=Pin.PASSIVE,do_erc=True),
            Pin(num='2',name='A',func=Pin.PASSIVE,do_erc=True)]),
        Part(name='MRA4003T3G',dest=TEMPLATE,tool=SKIDL,keywords='diode',description='1000V 1A General Purpose Rectifier Diode, SMA/DO-214AC',ref_prefix='D',num_units=1,fplist=['DO*214AC', '*SMA*'],do_erc=True,aliases=['MRA4004T3G', 'MRA4005T3G', 'MRA4006T3G', 'MRA4007T3G', 'NRVA4003T3G', 'NRVA4004T3G', 'NRVA4005T3G', 'NRVA4006T3G', 'NRVA4007T3G'],pins=[
            Pin(num='1',name='K',func=Pin.PASSIVE,do_erc=True),
            Pin(num='2',name='A',func=Pin.PASSIVE,do_erc=True)]),
        Part(name='Rohm_UMN1N',dest=TEMPLATE,tool=SKIDL,keywords='diode',description='High-speed switching diodes 2 pair Com A',ref_prefix='D',num_units=4,fplist=['*SOT-353*'],do_erc=True,aliases=['MMBD4448HCQW', 'Panasonic_MA5J002E'],pins=[
            Pin(num='1',name='A',func=Pin.PASSIVE,do_erc=True),
            Pin(num='2',name='K',func=Pin.PASSIVE,do_erc=True),
            Pin(num='2',name='K',func=Pin.PASSIVE,do_erc=True),
            Pin(num='3',name='A',func=Pin.PASSIVE,do_erc=True),
            Pin(num='2',name='K',func=Pin.PASSIVE,do_erc=True),
            Pin(num='4',name='A',func=Pin.PASSIVE,do_erc=True),
            Pin(num='2',name='K',func=Pin.PASSIVE,do_erc=True),
            Pin(num='5',name='A',func=Pin.PASSIVE,do_erc=True)]),
        Part(name='Rohm_UMP11N',dest=TEMPLATE,tool=SKIDL,keywords='diode',description='Ultra High Speed Switching Diode Array 2 pair Com A',ref_prefix='D',num_units=4,fplist=['*SC-70-6*', '*SC-88*', '*SOT-363*'],do_erc=True,aliases=['BAW56DW', 'BAW56S', 'MMBD4448HADW', 'Toshiba_HN1D01FU'],pins=[
            Pin(num='1',name='K',func=Pin.PASSIVE,do_erc=True),
            Pin(num='6',name='A',func=Pin.PASSIVE,do_erc=True),
            Pin(num='2',name='K',func=Pin.PASSIVE,do_erc=True),
            Pin(num='6',name='A',func=Pin.PASSIVE,do_erc=True),
            Pin(num='3',name='A',func=Pin.PASSIVE,do_erc=True),
            Pin(num='4',name='K',func=Pin.PASSIVE,do_erc=True),
            Pin(num='3',name='A',func=Pin.PASSIVE,do_erc=True),
            Pin(num='5',name='K',func=Pin.PASSIVE,do_erc=True)]),
        Part(name='SB120',dest=TEMPLATE,tool=SKIDL,keywords='diode Schottky',description='60V 1A Schottky Barrier Rectifier Diode, DO-41',ref_prefix='D',num_units=1,fplist=['D*SOD81*', 'D*DO?41*'],do_erc=True,aliases=['SB130', 'SB140', 'SB150', 'SB160', '1N5817', '1N5818', '1N5819'],pins=[
            Pin(num='1',name='K',func=Pin.PASSIVE,do_erc=True),
            Pin(num='2',name='A',func=Pin.PASSIVE,do_erc=True)]),
        Part(name='SM4001',dest=TEMPLATE,tool=SKIDL,keywords='diode',description='1800V 1A General Purpose Rectifier Diode, MELF',ref_prefix='D',num_units=1,fplist=['D*MELF*', 'MELF*'],do_erc=True,aliases=['SM4002', 'SM4003', 'SM4004', 'SM4005', 'SM4006', 'SM4007', 'SM513', 'SM516', 'SM518', 'SM2000'],pins=[
            Pin(num='1',name='K',func=Pin.PASSIVE,do_erc=True),
            Pin(num='2',name='A',func=Pin.PASSIVE,do_erc=True)]),
        Part(name='ZMDxx',dest=TEMPLATE,tool=SKIDL,keywords='zener diode',description='1000mW Zener Diode, MiniMELF',ref_prefix='D',num_units=1,fplist=['D*MiniMELF*', 'MiniMELF*'],do_erc=True,pins=[
            Pin(num='1',name='K',func=Pin.PASSIVE,do_erc=True),
            Pin(num='2',name='A',func=Pin.PASSIVE,do_erc=True)]),
        Part(name='ZMYxx',dest=TEMPLATE,tool=SKIDL,keywords='zener diode',description='1300mW Zener Diode, MELF',ref_prefix='D',num_units=1,fplist=['D*MELF*', 'MELF*'],do_erc=True,pins=[
            Pin(num='1',name='K',func=Pin.PASSIVE,do_erc=True),
            Pin(num='2',name='A',func=Pin.PASSIVE,do_erc=True)]),
        Part(name='ZPDxx',dest=TEMPLATE,tool=SKIDL,keywords='diode',description='500mW Zener Diode, DO-35',ref_prefix='D',num_units=1,fplist=['D*DO?35*', 'D*SOD27*'],do_erc=True,pins=[
            Pin(num='1',name='K',func=Pin.PASSIVE,do_erc=True),
            Pin(num='2',name='A',func=Pin.PASSIVE,do_erc=True)]),
        Part(name='ZPYxx',dest=TEMPLATE,tool=SKIDL,keywords='diode',description='1300mW Zener Diode, DO-41',ref_prefix='D',num_units=1,fplist=['D*DO?41*'],do_erc=True,pins=[
            Pin(num='1',name='K',func=Pin.PASSIVE,do_erc=True),
            Pin(num='2',name='A',func=Pin.PASSIVE,do_erc=True)])])